       IDENTIFICATION DIVISION.

       PROGRAM-ID.         CB2ALIGN.
      *AUTHOR.             ARNOLD J. TREMBLEY.
      *DATE-WRITTEN.       12/07/92.
       SKIP1
      ****************************************************************
      *SECURITY.           NONE.
      *        THIS PROGRAM IS PROVIDED FOR INSTRUCTIONAL
      *        PURPOSES ONLY.
      ****************************************************************
       SKIP2
      ****************************************************************
      *
      *   PROGRAM NAME:    CB2ALIGN.
      *   FUNCTION:        PERFORM THE FIRST PASS FOR CONVERSION OF
      *                    OS/VS COBOL INTO VS/COBOL II (ANSI 85).
      *                    LOCATE SPECIAL ITEMS TO BE MODIFIED.
      *
      *   LANGUAGE:        COBOL.
      *   SYSTEM NAME:     DEVELOPMENT TOOLS.
      *   FREQUENCY:       ON REQUEST.
      *   CLASSIFICATION:  BATCH.
      *
      *   PROCESSING:
      *
      *            THIS PROGRAM WILL PROCESS AN INPUT COBOL SOURCE
      *            PROGRAM FILE, ANALYZE ITS FORMAT, AND CREATE A
      *            MODIFIED SOURCE PROGRAM FILE IN A STANDARD
      *            FORMAT FOR "PRETTY PRINTING".
      *
      *|-----|--------|--------|------------|--------------------------|
      *| VER |  DATE  |  RPI   | PROGRAMMER |    MODIFICATIONS         |
      *|-----|--------|--------|------------|--------------------------|
      *| 01  |12/03/91| TEST   | A.TREMBLEY |ORIGINAL VERSION.         |
      *|     |        |        |            |VS COBOL II VERSION 3.1   |
      *|-----|--------|--------|------------|--------------------------|
      *| 02  |04/23/93| TEST   | A.TREMBLEY |ADDED 'NOHANDLE' OPTION TO|
      *|     |        |        |            |INSERT 'NOHANDLE' INTO    |
      *|     |        |        |            |'EXEC CICS' COMMANDS,     |
      *|     |        |        |            |ALIGNED EXEC AND END-EXEC.|
      *|-----|--------|--------|------------|--------------------------|
      *| 03  |08/27/93| TEST   | A.TREMBLEY |ADDED CONVERSION OF BLL   |
      *|     |        |        |            |CELLS AND SERVICE RELOADS |
      *|     |        |        |            |FOR CICS COBOL II.        |
      *|-----|--------|--------|------------|--------------------------|
      *| 04  |12/22/94| TEST   |ARNOLD J.   |MODIFIED TO SUPPORT A     |
      *|     |        |        |TREMBLEY    |MAXIMUM PROGRAM SIZE OF   |
      *|     |        |        |            |10,000 LINES.             |
      *|-----|--------|--------|------------|--------------------------|
      *| 05  |07/07/95| TEST   |ARNOLD J.   |DON'T INSERT 'NOHANDLE'   |
      *|     |        |        |TREMBLEY    |ON 'EXEC SQL' API CALLS.  |
      *|-----|--------|--------|------------|--------------------------|
      *| 99  |99/99/99| 99999  |XXXXXXXXXXXX|XXXXXXXXXXXXXXXXXXXXXXXXXX|
      *|     |        |        |            |XXXXXXXXXXXXXXXXXXXXXXXXXX|
      *|     |        |        |            |XXXXXXXXXXXXXXXXXXXXXXXXXX|
      *|-----|--------|--------|------------|--------------------------|
      ****************************************************************
       EJECT
      ****************************************************************
      *    E N V I R O N M E N T   D I V I S I O N .                 *
      ****************************************************************

       ENVIRONMENT DIVISION.

       CONFIGURATION SECTION.

       SOURCE-COMPUTER.        IBM-3090.
       OBJECT-COMPUTER.        IBM-3084.

       INPUT-OUTPUT SECTION.

       FILE-CONTROL.

           SELECT SYS001-COBOL-FILE    ASSIGN TO SYS001.

           SELECT SYS201-PRINT-FILE    ASSIGN TO SYS201.
       EJECT
      ****************************************************************
      *    D A T A   D I V I S I O N .                               *
      ****************************************************************

       DATA DIVISION.

       FILE SECTION.

       FD  SYS001-COBOL-FILE
           RECORDING MODE IS F
           RECORD CONTAINS 80 CHARACTERS
           BLOCK CONTAINS   0 RECORDS.

       01  SYS001-COBOL-RECORD         PIC X(80).

       FD  SYS201-PRINT-FILE
           RECORDING MODE IS F
           RECORD CONTAINS  80 CHARACTERS
           BLOCK CONTAINS    0 RECORDS.

       01  SYS201-PRINT-RECORD         PIC X(80).
       EJECT
      ****************************************************************
      *    W O R K I N G - S T O R A G E   S E C T I O N .           *
      ****************************************************************

       WORKING-STORAGE SECTION.

       01  000-CORE-IMAGE-ID           PIC X(32)   VALUE
              'CB2ALIGN BEGIN WORKING-STORAGE'.

       01  100-PROGRAM-SWITCHES.
           05  FILLER                  PIC X(32)   VALUE
              '****** 100-PROGRAM-FLAGS *******'.
           05  100-COBOL-EOF-FLAG      PIC X(01)   VALUE 'N'.
               88  88-100-ALL-TOKENS-PROCESSED     VALUE 'Y'.
           05  100-END-OF-TOKEN-FLAG   PIC X(01)   VALUE 'N'.
               88  88-100-START-OF-TOKEN           VALUE 'N'.
               88  88-100-END-OF-TOKEN             VALUE 'Y'.
           05  100-PRINT-CONTROL-FLAG  PIC X(01)   VALUE SPACE.
               88  88-100-NORMAL-PRINT             VALUE SPACE.
               88  88-100-TITLE-FOUND              VALUE 'T'.
               88  88-100-EJECT-FOUND              VALUE 'E'.
               88  88-100-SKIP1-FOUND              VALUE '1'.
               88  88-100-SKIP2-FOUND              VALUE '2'.
               88  88-100-SKIP3-FOUND              VALUE '3'.
           05  100-IDEN-DIV-FLAG       PIC X(01)   VALUE SPACE.
               88  88-100-IDEN-DIV-FOUND           VALUE 'Y'.
           05  100-ENVI-DIV-FLAG       PIC X(01)   VALUE SPACE.
               88  88-100-ENVI-DIV-FOUND           VALUE 'Y'.
           05  100-DATA-DIV-FLAG       PIC X(01)   VALUE SPACE.
               88  88-100-DATA-DIV-FOUND           VALUE 'Y'.
           05  100-PROC-DIV-FLAG       PIC X(01)   VALUE SPACE.
               88  88-100-PROC-DIV-FOUND           VALUE 'Y'.
           05  100-FIRST-PARA-FLAG     PIC X(01)   VALUE 'Y'.
               88  88-100-THIS-IS-FIRST-PARAGRAPH  VALUE 'Y'.
           05  100-QUOTE-FLAG          PIC X(01)   VALUE 'N'.
               88  88-100-NO-QUOTE-FOUND           VALUE 'N'.
               88  88-100-QUOTE-WAS-FOUND          VALUE 'Y'.
           05  100-PARA-COMMENT-FLAG   PIC X(01)   VALUE 'N'.
               88  88-100-NO-PARA-COMMENT          VALUE 'N'.
               88  88-100-BUILD-PARA-COMMENT       VALUE 'Y'.
           05  100-ALIGN-TARGET-FLAG   PIC X(01)   VALUE 'Y'.
               88  88-100-NO-ALIGN-TARGET          VALUE 'N'.
               88  88-100-ALIGN-TARGET             VALUE 'Y'.
           05  100-NOTE-VERB-FLAG      PIC X(01)   VALUE SPACE.
               88  88-100-NOTE-SCOPE-IS-OFF        VALUE SPACE.
               88  88-100-NOTE-PARANAME-FOUND      VALUE 'A'.
               88  88-100-NOTE-VERB-FIRST          VALUE 'L'.
               88  88-100-NOTE-VERB-BUT-SECOND     VALUE 'S'.
           05  100-CBL2-CURDATE-FLAG   PIC X(01)   VALUE 'N'.
               88  88-100-CBL2-CURDATE             VALUE 'Y'.
           05  100-CBL2-COMPILED-FLAG  PIC X(01)   VALUE 'N'.
               88  88-100-CBL2-COMPILED            VALUE 'Y'.
           05  100-CBL2-CURTOD-FLAG    PIC X(01)   VALUE 'N'.
               88  88-100-CBL2-CURTOD              VALUE 'Y'.
           05  100-NOHANDLE-FLAG       PIC X(01)   VALUE 'N'.
               88  88-100-INSERT-NOHANDLE          VALUE 'Y'.
           05  100-EXEC-CICS-FLAG      PIC X(01)   VALUE 'N'.
               88  88-100-END-EXEC-PROCESSED       VALUE 'N'.
               88  88-100-CICS-EXEC-FOUND          VALUE 'Y'.
           05  100-BAD-NOHANDLE-FLAG   PIC X(01)   VALUE 'N'.
               88  88-100-VALID-NOHANDLE           VALUE 'N'.
               88  88-100-NOHANDLE-IS-BAD          VALUE 'Y'.
           05  100-END-EXEC-FLAG       PIC X(01)   VALUE 'N'.
               88  88-100-NO-END-EXEC-FOUND        VALUE 'N'.
               88  88-100-END-EXEC-FOUND           VALUE 'Y'.
               88  88-100-END-EXECP-FOUND          VALUE 'P'.
           05  100-BLL-CAPTURE-FLAG    PIC X(01)   VALUE 'N'.
               88  88-100-NO-COMMAREA-FOUND        VALUE 'N'.
               88  88-100-COMMAREA-WAS-FOUND       VALUE 'F'.
               88  88-100-PARMLIST-WAS-FOUND       VALUE 'P'.
           05  100-FIRST-SERV-RELOAD   PIC X(01)   VALUE 'Y'.
       EJECT
      ****************************************************************
      *    200- PROGRAM RECORD LAYOUTS                               *
      ****************************************************************

       01  200-COBOL-RECORD.
           05  200-LINE-NUMBER             PIC X(06).
           05  200-INDICATOR-AREA          PIC X(01).
               88  88-200-COMMENT-LINE               VALUE '*'.
               88  88-200-EJECT-COMMENT              VALUE '/'.
               88  88-200-DEBUGGING-LINE             VALUE 'D'.
               88  88-200-CONTINUATION-LINE          VALUE '-'.
           05  200-SOURCE-CODE             PIC X(65).
           05  FILLER                      REDEFINES 200-SOURCE-CODE.
               10  200-SOURCE-CHAR         OCCURS 65 TIMES
                                           PIC X(01).
           05  FILLER                      REDEFINES 200-SOURCE-CODE.
               10  200-AREA-A              PIC X(04).
               10  FILLER                  PIC X(61).
           05  200-SOURCE-FILE-NAME        PIC X(08).
       SKIP2
       01  210-TOKEN-RECORD.
           05  210-LINE-NUMBER             PIC 9(05)   COMP-3 VALUE 0.
           05  210-TOKEN-START             PIC 9(03)   COMP-3 VALUE 0.
           05  210-TOKEN-LENGTH            PIC 9(03)   COMP-3 VALUE 0.
           05  210-TOKEN-TYPE              PIC X(01)   VALUE 'S'.
               88  88-210-TOKEN-IS-UNKNOWN             VALUE '?'.
               88  88-210-TOKEN-IS-IDENTIFIER          VALUE 'I'.
               88  88-210-TOKEN-IS-KEYWORD             VALUE 'K'.
               88  88-210-TOKEN-IS-NUMERIC-LIT         VALUE 'N'.
               88  88-210-TOKEN-IS-ALPHA-LIT           VALUE 'X'.
               88  88-210-TOKEN-IS-SPECIAL             VALUE '+'.
               88  88-210-TOKEN-IS-SOF                 VALUE 'S'.
               88  88-210-TOKEN-IS-EOL                 VALUE 'L'.
               88  88-210-TOKEN-IS-EOF                 VALUE 'E'.
           05  210-AREA-FLAG               PIC X(01)   VALUE 'A'.
               88  88-210-TOKEN-IS-IN-AREA-A           VALUE 'A'.
               88  88-210-TOKEN-IS-IN-AREA-B           VALUE 'B'.
           05  210-DIVISION-FLAG           PIC X(01)   VALUE 'I'.
               88  88-210-IDENTIFICATION-DIVISION      VALUE 'I'.
               88  88-210-ENVIRONMENT-DIVISION         VALUE 'E'.
               88  88-210-DATA-DIVISION                VALUE 'D'.
               88  88-210-PROCEDURE-DIVISION           VALUE 'P'.
           05  210-TOKEN-VALUE.
               10  210-TOKEN-BYTE          OCCURS 100 TIMES PIC X(01).
       EJECT
       01  220-LAST-TOKEN-RECORD.
           05  220-LAST-LINE-NUMBER        PIC 9(05)   COMP-3 VALUE 0.
           05  220-LAST-TOKEN-START        PIC 9(03)   COMP-3 VALUE 0.
           05  220-LAST-TOKEN-LENGTH       PIC 9(03)   COMP-3 VALUE 0.
           05  220-LAST-TOKEN-TYPE         PIC X(01)   VALUE 'S'.
               88  88-220-TOKEN-WAS-UNKNOWN            VALUE '?'.
               88  88-220-TOKEN-WAS-IDENTIFIER         VALUE 'I'.
               88  88-220-TOKEN-WAS-KEYWORD            VALUE 'K'.
               88  88-220-TOKEN-WAS-NUMERIC-LIT        VALUE 'N'.
               88  88-220-TOKEN-WAS-ALPHA-LIT          VALUE 'X'.
               88  88-220-TOKEN-WAS-SPECIAL            VALUE '+'.
               88  88-220-TOKEN-WAS-SOF                VALUE 'S'.
               88  88-220-TOKEN-WAS-EOL                VALUE 'L'.
               88  88-220-TOKEN-WAS-EOF                VALUE 'E'.
           05  220-LAST-AREA-FLAG          PIC X(01)   VALUE 'A'.
               88  88-220-TOKEN-WAS-IN-AREA-A          VALUE 'A'.
               88  88-220-TOKEN-WAS-IN-AREA-B          VALUE 'B'.
           05  220-LAST-DIVISION-FLAG      PIC X(01)   VALUE 'I'.
               88  88-220-IDENTIFICATION-DIVSION       VALUE 'I'.
               88  88-220-ENVIRONMENT-DIVISION         VALUE 'E'.
               88  88-220-DATA-DIVISION                VALUE 'D'.
               88  88-220-PROCEDURE-DIVISION           VALUE 'P'.
           05  220-LAST-TOKEN-VALUE        PIC X(100)  VALUE SPACES.
       SKIP2
       01  230-3RD-TOKEN-RECORD.
           05  230-3RD-LINE-NUMBER         PIC 9(05)   COMP-3 VALUE 0.
           05  230-3RD-TOKEN-START         PIC 9(03)   COMP-3 VALUE 0.
           05  230-3RD-TOKEN-LENGTH        PIC 9(03)   COMP-3 VALUE 0.
           05  230-3RD-TOKEN-TYPE          PIC X(01)   VALUE 'S'.
               88  88-230-TOKEN-WAS-UNKNOWN            VALUE '?'.
               88  88-230-TOKEN-WAS-IDENTIFIER         VALUE 'I'.
               88  88-230-TOKEN-WAS-KEYWORD            VALUE 'K'.
               88  88-230-TOKEN-WAS-NUMERIC-LIT        VALUE 'N'.
               88  88-230-TOKEN-WAS-ALPHA-LIT          VALUE 'X'.
               88  88-230-TOKEN-WAS-SPECIAL            VALUE '+'.
               88  88-230-TOKEN-WAS-SOF                VALUE 'S'.
               88  88-230-TOKEN-WAS-EOL                VALUE 'L'.
               88  88-230-TOKEN-WAS-EOF                VALUE 'E'.
           05  230-3RD-AREA-FLAG           PIC X(01)   VALUE 'A'.
               88  88-230-TOKEN-WAS-IN-AREA-A          VALUE 'A'.
               88  88-230-TOKEN-WAS-IN-AREA-B          VALUE 'B'.
           05  230-3RD-DIVISION-FLAG       PIC X(01)   VALUE 'I'.
               88  88-230-IDENTIFICATION-DIVSION       VALUE 'I'.
               88  88-230-ENVIRONMENT-DIVISION         VALUE 'E'.
               88  88-230-DATA-DIVISION                VALUE 'D'.
               88  88-230-PROCEDURE-DIVISION           VALUE 'P'.
           05  230-3RD-TOKEN-VALUE         PIC X(100)  VALUE SPACES.
       EJECT
       01  240-4TH-TOKEN-RECORD.
           05  240-4TH-LINE-NUMBER         PIC 9(05)   COMP-3 VALUE 0.
           05  240-4TH-TOKEN-START         PIC 9(03)   COMP-3 VALUE 0.
           05  240-4TH-TOKEN-LENGTH        PIC 9(03)   COMP-3 VALUE 0.
           05  240-4TH-TOKEN-TYPE          PIC X(01)   VALUE 'S'.
               88  88-240-TOKEN-WAS-UNKNOWN            VALUE '?'.
               88  88-240-TOKEN-WAS-IDENTIFIER         VALUE 'I'.
               88  88-240-TOKEN-WAS-KEYWORD            VALUE 'K'.
               88  88-240-TOKEN-WAS-NUMERIC-LIT        VALUE 'N'.
               88  88-240-TOKEN-WAS-ALPHA-LIT          VALUE 'X'.
               88  88-240-TOKEN-WAS-SPECIAL            VALUE '+'.
               88  88-240-TOKEN-WAS-SOF                VALUE 'S'.
               88  88-240-TOKEN-WAS-EOL                VALUE 'L'.
               88  88-240-TOKEN-WAS-EOF                VALUE 'E'.
           05  240-4TH-AREA-FLAG           PIC X(01)   VALUE 'A'.
               88  88-240-TOKEN-WAS-IN-AREA-A          VALUE 'A'.
               88  88-240-TOKEN-WAS-IN-AREA-B          VALUE 'B'.
           05  230-4TH-DIVISION-FLAG       PIC X(01)   VALUE 'I'.
               88  88-240-IDENTIFICATION-DIVSION       VALUE 'I'.
               88  88-240-ENVIRONMENT-DIVISION         VALUE 'E'.
               88  88-240-DATA-DIVISION                VALUE 'D'.
               88  88-240-PROCEDURE-DIVISION           VALUE 'P'.
           05  240-4TH-TOKEN-VALUE         PIC X(100)  VALUE SPACES.

       01  290-RUN-TIME-PARAMETER-CARD.
           05  290-RUNTIME-PARMS           PIC X(80)   VALUE SPACES.
       EJECT
      ****************************************************************
      *    300- PROGRAM CONSTANTS AND LITERALS                       *
      ****************************************************************

       01  300-PROGRAM-CONSTANTS.
           05  FILLER                  PIC X(32)   VALUE
              '***** 300-PROGRAM-CONSTANTS ****'.
           05  300-CHAR-1              PIC X(01)   VALUE '1'.
           05  300-CHAR-2              PIC X(01)   VALUE '2'.
           05  300-CHAR-3              PIC X(01)   VALUE '3'.
           05  300-CHAR-B              PIC X(01)   VALUE 'B'.
           05  300-CHAR-C              PIC X(01)   VALUE 'C'.
           05  300-CHAR-E              PIC X(01)   VALUE 'E'.
           05  300-CHAR-F              PIC X(01)   VALUE 'F'.
           05  300-CHAR-H              PIC X(01)   VALUE 'H'.
           05  300-CHAR-N              PIC X(01)   VALUE 'N'.
           05  300-CHAR-P              PIC X(01)   VALUE 'P'.
           05  300-CHAR-S              PIC X(01)   VALUE 'S'.
           05  300-CHAR-W              PIC X(01)   VALUE 'W'.
           05  300-CHAR-X              PIC X(01)   VALUE 'X'.
           05  300-CHAR-PLUS           PIC X(01)   VALUE '+'.
           05  300-CHAR-HYPHEN         PIC X(01)   VALUE '-'.
           05  300-CHAR-ASTERISK       PIC X(01)   VALUE '*'.
           05  300-CHAR-SLASH          PIC X(01)   VALUE '/'.
           05  300-CHAR-PERIOD         PIC X(01)   VALUE '.'.
           05  300-CHAR-COMMA          PIC X(01)   VALUE ','.
           05  300-CHAR-COLON          PIC X(01)   VALUE ':'.
           05  300-LEFT-PARENS         PIC X(01)   VALUE '('.
           05  300-RIGHT-PARENS        PIC X(01)   VALUE ')'.
           05  300-CHAR-EQUAL          PIC X(01)   VALUE '='.
           05  300-CHAR-GREATER-THAN   PIC X(01)   VALUE '>'.
           05  300-CHAR-LESS-THAN      PIC X(01)   VALUE '<'.
           05  300-EIGHT-QUESTIONS     PIC X(08)   VALUE '????????'.
           05  300-INITIAL-PARA-4      PIC X(05)   VALUE '0000-'.
           05  300-INITIAL-PARA-5      PIC X(06)   VALUE '00000-'.
           05  300-COBOL-01            PIC X(02)   VALUE '01'.
           05  300-COBOL-66            PIC X(02)   VALUE '66'.
           05  300-COBOL-77            PIC X(02)   VALUE '77'.
           05  300-COBOL-88            PIC X(02)   VALUE '88'.
           05  300-ELEMENTARY          PIC X(02)   VALUE 'EL'.
           05  300-GROUP-ITEM          PIC X(02)   VALUE 'GR'.
       EJECT
      ****************************************************************
      *    300- NUMERIC CONSTANTS                                    *
      ****************************************************************
           05  300-MINUS-ONE           PIC S9(04)  COMP SYNC VALUE -1.
           05  300-COMP-1              PIC S9(04)  COMP   VALUE +1.
           05  300-COMP-2              PIC S9(04)  COMP   VALUE +2.
           05  300-COMP-4              PIC S9(04)  COMP   VALUE +4.
           05  300-COMP-5              PIC S9(04)  COMP   VALUE +5.
           05  300-COMP-6              PIC S9(04)  COMP   VALUE +6.
           05  300-COMP-8              PIC S9(04)  COMP   VALUE +8.
           05  300-COMP-9              PIC S9(04)  COMP   VALUE +9.
           05  300-COMP-10             PIC S9(04)  COMP   VALUE +10.
           05  300-COMP-12             PIC S9(04)  COMP   VALUE +12.
           05  300-COMP-16             PIC S9(04)  COMP   VALUE +16.
           05  300-COMP-20             PIC S9(04)  COMP   VALUE +20.
           05  300-COMP-25             PIC S9(04)  COMP   VALUE +25.
           05  300-COMP-30             PIC S9(04)  COMP   VALUE +30.
           05  300-COMP-33             PIC S9(04)  COMP   VALUE +33.
           05  300-COMP-37             PIC S9(04)  COMP   VALUE +37.
           05  300-COMP-49             PIC S9(04)  COMP   VALUE +49.
           05  300-COMP-63             PIC S9(04)  COMP   VALUE +63.
           05  300-COMP-65             PIC S9(04)  COMP   VALUE +65.
           05  300-ONE                 PIC S9(03)  COMP-3 VALUE +1.
           05  300-TWO                 PIC S9(03)  COMP-3 VALUE +2.
           05  300-THREE               PIC S9(03)  COMP-3 VALUE +3.
           05  300-FIVE                PIC S9(05)  COMP-3 VALUE +5.
           05  300-LINE-SCAN-LENGTH    PIC S9(03)  COMP-3 VALUE +065.
           05  300-MAXIMUM-PL          PIC S9(09)  COMP   VALUE +10000.
       EJECT
      ****************************************************************
      *    300- COBOL RESERVED WORDS                                 *
      ****************************************************************
           05  300-TITLE               PIC X(05)   VALUE 'TITLE'.
           05  300-EJECT               PIC X(05)   VALUE 'EJECT'.
           05  300-SKIP1               PIC X(05)   VALUE 'SKIP1'.
           05  300-SKIP2               PIC X(05)   VALUE 'SKIP2'.
           05  300-SKIP3               PIC X(05)   VALUE 'SKIP3'.
           05  300-PROGRAM-ID          PIC X(10)   VALUE 'PROGRAM-ID'.
           05  300-SELECT              PIC X(06)   VALUE 'SELECT'.
           05  300-ASSIGN              PIC X(06)   VALUE 'ASSIGN'.
           05  300-COBOL-FD            PIC X(02)   VALUE 'FD'.
           05  300-COBOL-SD            PIC X(02)   VALUE 'SD'.
           05  300-FILE                PIC X(04)   VALUE 'FILE'.
           05  300-CONFIGURATION       PIC X(13)   VALUE
               'CONFIGURATION'.
           05  300-INPUT-OUTPUT        PIC X(12)   VALUE
               'INPUT-OUTPUT'.
           05  300-WORKING-STORAGE     PIC X(15)   VALUE
               'WORKING-STORAGE'.
           05  300-LINKAGE             PIC X(07)   VALUE 'LINKAGE'.
           05  300-DIVISION            PIC X(08)   VALUE 'DIVISION'.
           05  300-SECTION             PIC X(07)   VALUE 'SECTION'.
           05  300-ID                  PIC X(02)   VALUE 'ID'.
           05  300-IDENTIFICATION      PIC X(14)   VALUE
               'IDENTIFICATION'.
           05  300-ENVIRONMENT         PIC X(11)   VALUE 'ENVIRONMENT'.
           05  300-DATA                PIC X(04)   VALUE 'DATA'.
           05  300-PROCEDURE           PIC X(09)   VALUE 'PROCEDURE'.
           05  300-FILLER              PIC X(06)   VALUE 'FILLER'.
           05  300-PICTURE.
               10  300-PIC             PIC X(03)   VALUE 'PIC'.
               10  FILLER              PIC X(04)   VALUE 'TURE'.
           05  300-OCCURS              PIC X(06)   VALUE 'OCCURS'.
           05  300-VALUES.
               10  300-VALUE           PIC X(05)   VALUE 'VALUE'.
               10  FILLER              PIC X(01)   VALUE 'S'.
           05  300-LIT-COMP-3.
               10  300-LIT-COMP        PIC X(04)   VALUE 'COMP'.
               10  FILLER              PIC X(02)   VALUE '-3'.
           05  300-REDEFINES           PIC X(09)   VALUE 'REDEFINES'.
           05  300-IS                  PIC X(02)   VALUE 'IS'.
           05  300-AT                  PIC X(02)   VALUE 'AT'.
           05  300-ON                  PIC X(02)   VALUE 'ON'.
           05  300-IF                  PIC X(02)   VALUE 'IF'.
           05  300-NOT                 PIC X(03)   VALUE 'NOT'.
           05  300-THEN                PIC X(04)   VALUE 'THEN'.
           05  300-ELSE                PIC X(04)   VALUE 'ELSE'.
           05  300-WHEN                PIC X(04)   VALUE 'WHEN'.
           05  300-FROM                PIC X(04)   VALUE 'FROM'.
           05  300-BY                  PIC X(02)   VALUE 'BY'.
           05  300-MOVE                PIC X(04)   VALUE 'MOVE'.
           05  300-NOTE                PIC X(04)   VALUE 'NOTE'.
           05  300-COMPUTE             PIC X(07)   VALUE 'COMPUTE'.
           05  300-EXAMINE             PIC X(07)   VALUE 'EXAMINE'.
           05  300-DISPLAY             PIC X(07)   VALUE 'DISPLAY'.
           05  300-ADD                 PIC X(03)   VALUE 'ADD'.
           05  300-SUBTRACT            PIC X(08)   VALUE 'SUBTRACT'.
           05  300-MULTIPLY            PIC X(08)   VALUE 'MULTIPLY'.
           05  300-PERFORM             PIC X(07)   VALUE 'PERFORM'.
           05  300-THRU                PIC X(04)   VALUE 'THRU'.
           05  300-THROUGH             PIC X(07)   VALUE 'THROUGH'.
           05  300-EXIT                PIC X(04)   VALUE 'EXIT'.
           05  300-PROGRAM             PIC X(07)   VALUE 'PROGRAM'.
           05  300-CALL                PIC X(04)   VALUE 'CALL'.
           05  300-ALL                 PIC X(03)   VALUE 'ALL'.
           05  300-ALTER               PIC X(05)   VALUE 'ALTER'.
           05  300-START               PIC X(05)   VALUE 'START'.
           05  300-GO                  PIC X(02)   VALUE 'GO'.
           05  300-TO                  PIC X(02)   VALUE 'TO'.
           05  300-SORT                PIC X(04)   VALUE 'SORT'.
           05  300-OPEN                PIC X(04)   VALUE 'OPEN'.
           05  300-CLOSE               PIC X(05)   VALUE 'CLOSE'.
           05  300-READ                PIC X(04)   VALUE 'READ'.
           05  300-WRITE               PIC X(05)   VALUE 'WRITE'.
           05  300-TRACE               PIC X(05)   VALUE 'TRACE'.
           05  300-UNTIL               PIC X(05)   VALUE 'UNTIL'.
           05  300-USING               PIC X(05)   VALUE 'USING'.
           05  300-TIMES               PIC X(05)   VALUE 'TIMES'.
           05  300-EVALUATE            PIC X(08)   VALUE 'EVALUATE'.
           05  300-EXHIBIT             PIC X(07)   VALUE 'EXHIBIT'.
           05  300-VARYING             PIC X(07)   VALUE 'VARYING'.
           05  300-LEADING             PIC X(07)   VALUE 'LEADING'.
           05  300-TRAILING            PIC X(08)   VALUE 'TRAILING'.
           05  300-INVALID             PIC X(07)   VALUE 'INVALID'.
           05  300-REWRITE             PIC X(07)   VALUE 'REWRITE'.
           05  300-DELETE              PIC X(06)   VALUE 'DELETE'.
           05  300-RETURN              PIC X(06)   VALUE 'RETURN'.
           05  300-GOBACK              PIC X(06)   VALUE 'GOBACK'.
           05  300-DIVIDE              PIC X(06)   VALUE 'DIVIDE'.
           05  300-SEARCH              PIC X(06)   VALUE 'SEARCH'.
           05  300-STOP                PIC X(04)   VALUE 'STOP'.
           05  300-RUN                 PIC X(03)   VALUE 'RUN'.
           05  300-SQL                 PIC X(03)   VALUE 'SQL'.
           05  300-EXEC                PIC X(04)   VALUE 'EXEC'.
           05  300-CICS                PIC X(04)   VALUE 'CICS'.
           05  300-NOHANDLE            PIC X(08)   VALUE 'NOHANDLE'.
           05  300-HANDLE              PIC X(06)   VALUE 'HANDLE'.
           05  300-IGNORE              PIC X(06)   VALUE 'IGNORE'.
           05  300-RESP                PIC X(04)   VALUE 'RESP'.
           05  300-ENQ                 PIC X(03)   VALUE 'ENQ'.
           05  300-END-EXECP           PIC X(09)   VALUE 'END-EXEC.'.
           05  300-END-EXEC            PIC X(08)   VALUE 'END-EXEC'.
           05  300-DFHCOMMAREA         PIC X(11)   VALUE
               'DFHCOMMAREA'.
       SKIP3
      ****************************************************************
      *    400- PROGRAM COUNTERS                                     *
      ****************************************************************

       01  400-PROGRAM-COUNTERS.
           05  FILLER                  PIC X(32)   VALUE
              '***** 400-PROGRAM-COUNTERS *****'.
           05  400-COBOL-LINE-COUNT    PIC 9(5)    COMP-3 VALUE ZERO.
           05  400-TABLE-LINE-COUNT    PIC 9(5)    COMP-3 VALUE ZERO.
           05  400-PRINT-LINE-COUNT    PIC 9(5)    COMP-3 VALUE ZERO.
           05  400-OLD-LINES-DROPPED   PIC 9(5)    COMP-3 VALUE ZERO.
           05  400-NEW-LINES-ADDED     PIC 9(5)    COMP-3 VALUE ZERO.
           05  400-TOKEN-COUNT         PIC 9(7)    COMP-3 VALUE ZERO.
           05  400-STAR-COUNT          PIC 9(3)    COMP-3 VALUE ZERO.
           05  400-NON-STAR-COUNT      PIC 9(3)    COMP-3 VALUE ZERO.
           05  400-PARENS-NESTING      PIC 9(3)    COMP-3 VALUE ZERO.
           05  400-HIGH-USED-PL        PIC S9(8)   COMP   VALUE ZERO.
           05  400-REMAINDER           PIC S9(4)   COMP   VALUE ZERO.
           05  400-TOKEN-LETTERS       PIC 9(3)    COMP-3 VALUE ZERO.
           05  400-TOKEN-NUMBERS       PIC 9(3)    COMP-3 VALUE ZERO.
           05  400-TOKEN-HYPHENS       PIC 9(3)    COMP-3 VALUE ZERO.
           05  400-CICS-EXEC-POS       PIC 9(3)    COMP-3 VALUE ZERO.
           05  400-CICS-PTR-COUNT      PIC 9(3)    COMP-3 VALUE ZERO.
           05  400-DOT-COUNT           PIC 9(3)    COMP-3 VALUE ZERO.
       EJECT
      ****************************************************************
      *    500- PROGRAM DATA TABLES                                  *
      ****************************************************************

       01  500-CICS-POINTER-TABLE.
           05  500-CICS-PTR-ENTRY          OCCURS 50 TIMES
                                           INDEXED BY PT.
               10  500-CICS-BLL-ADDR       PIC X(30)   VALUE SPACES.
               10  500-CICS-BLL-PTR        PIC X(30)   VALUE SPACES.
               10  500-CICS-BLL-DSECT      PIC X(30)   VALUE SPACES.

       01  550-RESERVED-WORD-DATA.
           05  FILLER   PIC X(16)  VALUE 'ACCEPT          '.
           05  FILLER   PIC X(16)  VALUE 'ACCESS          '.
           05  FILLER   PIC X(16)  VALUE 'ADD             '.
           05  FILLER   PIC X(16)  VALUE 'ADDRESS         '.
           05  FILLER   PIC X(16)  VALUE 'ADVANCING       '.
           05  FILLER   PIC X(16)  VALUE 'AFTER           '.
           05  FILLER   PIC X(16)  VALUE 'ALL             '.
           05  FILLER   PIC X(16)  VALUE 'ALPHABET        '.
           05  FILLER   PIC X(16)  VALUE 'ALPHABETIC      '.
           05  FILLER   PIC X(16)  VALUE 'ALPHABETIC-LOWER'.
           05  FILLER   PIC X(16)  VALUE 'ALPHABETIC-UPPER'.
           05  FILLER   PIC X(16)  VALUE 'ALPHANUMERIC    '.
           05  FILLER   PIC X(16)  VALUE 'ALSO            '.
           05  FILLER   PIC X(16)  VALUE 'ALTER           '.
           05  FILLER   PIC X(16)  VALUE 'ALTERNATE       '.
           05  FILLER   PIC X(16)  VALUE 'AND             '.
           05  FILLER   PIC X(16)  VALUE 'ANY             '.
           05  FILLER   PIC X(16)  VALUE 'APPLY           '.
           05  FILLER   PIC X(16)  VALUE 'ARE             '.
           05  FILLER   PIC X(16)  VALUE 'AREA            '.
           05  FILLER   PIC X(16)  VALUE 'AREAS           '.
           05  FILLER   PIC X(16)  VALUE 'ARITHMETIC      '.
           05  FILLER   PIC X(16)  VALUE 'ASCENDING       '.
           05  FILLER   PIC X(16)  VALUE 'ASSIGN          '.
           05  FILLER   PIC X(16)  VALUE 'AT              '.
           05  FILLER   PIC X(16)  VALUE 'AUTHOR          '.
           05  FILLER   PIC X(16)  VALUE 'B-AND           '.
           05  FILLER   PIC X(16)  VALUE 'B-EXOR          '.
           05  FILLER   PIC X(16)  VALUE 'B-LESS          '.
           05  FILLER   PIC X(16)  VALUE 'B-NOT           '.
           05  FILLER   PIC X(16)  VALUE 'B-OR            '.
           05  FILLER   PIC X(16)  VALUE 'BASIS           '.
           05  FILLER   PIC X(16)  VALUE 'BEFORE          '.
           05  FILLER   PIC X(16)  VALUE 'BEGINNING       '.
           05  FILLER   PIC X(16)  VALUE 'BINARY          '.
           05  FILLER   PIC X(16)  VALUE 'BIT             '.
           05  FILLER   PIC X(16)  VALUE 'BITS            '.
           05  FILLER   PIC X(16)  VALUE 'BLANK           '.
           05  FILLER   PIC X(16)  VALUE 'BLOCK           '.
           05  FILLER   PIC X(16)  VALUE 'BOOLEAN         '.
           05  FILLER   PIC X(16)  VALUE 'BOTTOM          '.
           05  FILLER   PIC X(16)  VALUE 'BY              '.
           05  FILLER   PIC X(16)  VALUE 'CALL            '.
           05  FILLER   PIC X(16)  VALUE 'CANCEL          '.
           05  FILLER   PIC X(16)  VALUE 'CBL             '.
           05  FILLER   PIC X(16)  VALUE 'CD              '.
           05  FILLER   PIC X(16)  VALUE 'CF              '.
           05  FILLER   PIC X(16)  VALUE 'CH              '.
           05  FILLER   PIC X(16)  VALUE 'CHARACTER       '.
           05  FILLER   PIC X(16)  VALUE 'CHARACTERS      '.
           05  FILLER   PIC X(16)  VALUE 'CICS            '.
           05  FILLER   PIC X(16)  VALUE 'CLASS           '.
           05  FILLER   PIC X(16)  VALUE 'CLOCK-UNITS     '.
           05  FILLER   PIC X(16)  VALUE 'CLOSE           '.
           05  FILLER   PIC X(16)  VALUE 'COBOL           '.
           05  FILLER   PIC X(16)  VALUE 'CODE            '.
           05  FILLER   PIC X(16)  VALUE 'CODE-SET        '.
           05  FILLER   PIC X(16)  VALUE 'COLLATING       '.
           05  FILLER   PIC X(16)  VALUE 'COLUMN          '.
           05  FILLER   PIC X(16)  VALUE 'COM-REG         '.
           05  FILLER   PIC X(16)  VALUE 'COMMA           '.
           05  FILLER   PIC X(16)  VALUE 'COMMIT          '.
           05  FILLER   PIC X(16)  VALUE 'COMMON          '.
           05  FILLER   PIC X(16)  VALUE 'COMMUNICATION   '.
           05  FILLER   PIC X(16)  VALUE 'COMP            '.
           05  FILLER   PIC X(16)  VALUE 'COMP-1          '.
           05  FILLER   PIC X(16)  VALUE 'COMP-2          '.
           05  FILLER   PIC X(16)  VALUE 'COMP-3          '.
           05  FILLER   PIC X(16)  VALUE 'COMP-4          '.
           05  FILLER   PIC X(16)  VALUE 'COMP-5          '.
           05  FILLER   PIC X(16)  VALUE 'COMP-6          '.
           05  FILLER   PIC X(16)  VALUE 'COMP-7          '.
           05  FILLER   PIC X(16)  VALUE 'COMP-8          '.
           05  FILLER   PIC X(16)  VALUE 'COMP-9          '.
           05  FILLER   PIC X(16)  VALUE 'COMPUTATIONAL   '.
           05  FILLER   PIC X(16)  VALUE 'COMPUTATIONAL-1 '.
           05  FILLER   PIC X(16)  VALUE 'COMPUTATIONAL-2 '.
           05  FILLER   PIC X(16)  VALUE 'COMPUTATIONAL-3 '.
           05  FILLER   PIC X(16)  VALUE 'COMPUTATIONAL-4 '.
           05  FILLER   PIC X(16)  VALUE 'COMPUTATIONAL-5 '.
           05  FILLER   PIC X(16)  VALUE 'COMPUTATIONAL-6 '.
           05  FILLER   PIC X(16)  VALUE 'COMPUTATIONAL-7 '.
           05  FILLER   PIC X(16)  VALUE 'COMPUTATIONAL-8 '.
           05  FILLER   PIC X(16)  VALUE 'COMPUTATIONAL-9 '.
           05  FILLER   PIC X(16)  VALUE 'COMPUTE         '.
           05  FILLER   PIC X(16)  VALUE 'CONFIGURATION   '.
           05  FILLER   PIC X(16)  VALUE 'CONNECT         '.
           05  FILLER   PIC X(16)  VALUE 'CONTAINED       '.
           05  FILLER   PIC X(16)  VALUE 'CONTAINS        '.
           05  FILLER   PIC X(16)  VALUE 'CONTENT         '.
           05  FILLER   PIC X(16)  VALUE 'CONTINUE        '.
           05  FILLER   PIC X(16)  VALUE 'CONTROL         '.
           05  FILLER   PIC X(16)  VALUE 'CONTROLS        '.
           05  FILLER   PIC X(16)  VALUE 'CONVERTING      '.
           05  FILLER   PIC X(16)  VALUE 'COPY            '.
           05  FILLER   PIC X(16)  VALUE 'CORR            '.
           05  FILLER   PIC X(16)  VALUE 'CORRESPONDING   '.
           05  FILLER   PIC X(16)  VALUE 'COUNT           '.
           05  FILLER   PIC X(16)  VALUE 'CURRENCY        '.
           05  FILLER   PIC X(16)  VALUE 'CURRENT         '.
           05  FILLER   PIC X(16)  VALUE 'DATA            '.
           05  FILLER   PIC X(16)  VALUE 'DATE            '.
           05  FILLER   PIC X(16)  VALUE 'DATE-COMPILED   '.
           05  FILLER   PIC X(16)  VALUE 'DATE-WRITTEN    '.
           05  FILLER   PIC X(16)  VALUE 'DAY             '.
           05  FILLER   PIC X(16)  VALUE 'DAY-OF-WEEK     '.
           05  FILLER   PIC X(16)  VALUE 'DB              '.
           05  FILLER   PIC X(16)  VALUE 'DB-DATA-NAME    '.
           05  FILLER   PIC X(16)  VALUE 'DB-EXCEPTION    '.
           05  FILLER   PIC X(16)  VALUE 'DB-RECORD-NAME  '.
           05  FILLER   PIC X(16)  VALUE 'DB-SET-NAME     '.
           05  FILLER   PIC X(16)  VALUE 'DB-STATUS       '.
           05  FILLER   PIC X(16)  VALUE 'DBCS            '.
           05  FILLER   PIC X(16)  VALUE 'DE              '.
           05  FILLER   PIC X(16)  VALUE 'DEBUG-CONTENTS  '.
           05  FILLER   PIC X(16)  VALUE 'DEBUG-ITEM      '.
           05  FILLER   PIC X(16)  VALUE 'DEBUG-LINE      '.
           05  FILLER   PIC X(16)  VALUE 'DEBUG-NAME      '.
           05  FILLER   PIC X(16)  VALUE 'DEBUG-SUB-1     '.
           05  FILLER   PIC X(16)  VALUE 'DEBUG-SUB-2     '.
           05  FILLER   PIC X(16)  VALUE 'DEBUG-SUB-3     '.
           05  FILLER   PIC X(16)  VALUE 'DEBUGGING       '.
           05  FILLER   PIC X(16)  VALUE 'DECIMAL-POINT   '.
           05  FILLER   PIC X(16)  VALUE 'DECLARATIVES    '.
           05  FILLER   PIC X(16)  VALUE 'DEFAULT         '.
           05  FILLER   PIC X(16)  VALUE 'DELETE          '.
           05  FILLER   PIC X(16)  VALUE 'DELIMITED       '.
           05  FILLER   PIC X(16)  VALUE 'DELIMITER       '.
           05  FILLER   PIC X(16)  VALUE 'DEPENDING       '.
           05  FILLER   PIC X(16)  VALUE 'DESCENDING      '.
           05  FILLER   PIC X(16)  VALUE 'DESTINATION     '.
           05  FILLER   PIC X(16)  VALUE 'DETAIL          '.
           05  FILLER   PIC X(16)  VALUE 'DISABLE         '.
           05  FILLER   PIC X(16)  VALUE 'DISCONNECT      '.
           05  FILLER   PIC X(16)  VALUE 'DISPLAY         '.
           05  FILLER   PIC X(16)  VALUE 'DISPLAY-1       '.
           05  FILLER   PIC X(16)  VALUE 'DISPLAY-2       '.
           05  FILLER   PIC X(16)  VALUE 'DISPLAY-3       '.
           05  FILLER   PIC X(16)  VALUE 'DISPLAY-4       '.
           05  FILLER   PIC X(16)  VALUE 'DISPLAY-5       '.
           05  FILLER   PIC X(16)  VALUE 'DISPLAY-6       '.
           05  FILLER   PIC X(16)  VALUE 'DISPLAY-7       '.
           05  FILLER   PIC X(16)  VALUE 'DISPLAY-8       '.
           05  FILLER   PIC X(16)  VALUE 'DISPLAY-9       '.
           05  FILLER   PIC X(16)  VALUE 'DIVIDE          '.
           05  FILLER   PIC X(16)  VALUE 'DIVISION        '.
           05  FILLER   PIC X(16)  VALUE 'DOWN            '.
           05  FILLER   PIC X(16)  VALUE 'DUPLICATE       '.
           05  FILLER   PIC X(16)  VALUE 'DUPLICATES      '.
           05  FILLER   PIC X(16)  VALUE 'DYNAMIC         '.
           05  FILLER   PIC X(16)  VALUE 'EGCS            '.
           05  FILLER   PIC X(16)  VALUE 'EGI             '.
           05  FILLER   PIC X(16)  VALUE 'EJECT           '.
           05  FILLER   PIC X(16)  VALUE 'ELSE            '.
           05  FILLER   PIC X(16)  VALUE 'EMI             '.
           05  FILLER   PIC X(16)  VALUE 'EMPTY           '.
           05  FILLER   PIC X(16)  VALUE 'ENABLE          '.
           05  FILLER   PIC X(16)  VALUE 'END             '.
           05  FILLER   PIC X(16)  VALUE 'END-ADD         '.
           05  FILLER   PIC X(16)  VALUE 'END-CALL        '.
           05  FILLER   PIC X(16)  VALUE 'END-COMPUTE     '.
           05  FILLER   PIC X(16)  VALUE 'END-DELETE      '.
           05  FILLER   PIC X(16)  VALUE 'END-DISABLE     '.
           05  FILLER   PIC X(16)  VALUE 'END-DIVIDE      '.
           05  FILLER   PIC X(16)  VALUE 'END-ENABLE      '.
           05  FILLER   PIC X(16)  VALUE 'END-EVALUATE    '.
           05  FILLER   PIC X(16)  VALUE 'END-EXEC        '.
           05  FILLER   PIC X(16)  VALUE 'END-IF          '.
           05  FILLER   PIC X(16)  VALUE 'END-MULTIPLY    '.
           05  FILLER   PIC X(16)  VALUE 'END-OF-PAGE     '.
           05  FILLER   PIC X(16)  VALUE 'END-PERFORM     '.
           05  FILLER   PIC X(16)  VALUE 'END-READ        '.
           05  FILLER   PIC X(16)  VALUE 'END-RECEIVE     '.
           05  FILLER   PIC X(16)  VALUE 'END-READ        '.
           05  FILLER   PIC X(16)  VALUE 'END-RETURN      '.
           05  FILLER   PIC X(16)  VALUE 'END-REWRITE     '.
           05  FILLER   PIC X(16)  VALUE 'END-SEARCH      '.
           05  FILLER   PIC X(16)  VALUE 'END-SEND        '.
           05  FILLER   PIC X(16)  VALUE 'END-START       '.
           05  FILLER   PIC X(16)  VALUE 'END-STRING      '.
           05  FILLER   PIC X(16)  VALUE 'END-SUBTRACT    '.
           05  FILLER   PIC X(16)  VALUE 'END-TRANSCEIVE  '.
           05  FILLER   PIC X(16)  VALUE 'END-UNSTRING    '.
           05  FILLER   PIC X(16)  VALUE 'END-WRITE       '.
           05  FILLER   PIC X(16)  VALUE 'ENDING          '.
           05  FILLER   PIC X(16)  VALUE 'ENTER           '.
           05  FILLER   PIC X(16)  VALUE 'ENTRY           '.
           05  FILLER   PIC X(16)  VALUE 'ENVIRONMENT     '.
           05  FILLER   PIC X(16)  VALUE 'EOP             '.
           05  FILLER   PIC X(16)  VALUE 'EQUAL           '.
           05  FILLER   PIC X(16)  VALUE 'EQUALS          '.
           05  FILLER   PIC X(16)  VALUE 'ERASE           '.
           05  FILLER   PIC X(16)  VALUE 'ERROR           '.
           05  FILLER   PIC X(16)  VALUE 'ESI             '.
           05  FILLER   PIC X(16)  VALUE 'EVALUATE        '.
           05  FILLER   PIC X(16)  VALUE 'EVERY           '.
           05  FILLER   PIC X(16)  VALUE 'EXACT           '.
           05  FILLER   PIC X(16)  VALUE 'EXCEEDS         '.
           05  FILLER   PIC X(16)  VALUE 'EXCEPTION       '.
           05  FILLER   PIC X(16)  VALUE 'EXCLUSIVE       '.
           05  FILLER   PIC X(16)  VALUE 'EXEC            '.
           05  FILLER   PIC X(16)  VALUE 'EXIT            '.
           05  FILLER   PIC X(16)  VALUE 'EXTEND          '.
           05  FILLER   PIC X(16)  VALUE 'EXTERNAL        '.
           05  FILLER   PIC X(16)  VALUE 'FALSE           '.
           05  FILLER   PIC X(16)  VALUE 'FD              '.
           05  FILLER   PIC X(16)  VALUE 'FETCH           '.
           05  FILLER   PIC X(16)  VALUE 'FILE            '.
           05  FILLER   PIC X(16)  VALUE 'FILE-CONTROL    '.
           05  FILLER   PIC X(16)  VALUE 'FILLER          '.
           05  FILLER   PIC X(16)  VALUE 'FINAL           '.
           05  FILLER   PIC X(16)  VALUE 'FIND            '.
           05  FILLER   PIC X(16)  VALUE 'FINISH          '.
           05  FILLER   PIC X(16)  VALUE 'FIRST           '.
           05  FILLER   PIC X(16)  VALUE 'FOOTING         '.
           05  FILLER   PIC X(16)  VALUE 'FOR             '.
           05  FILLER   PIC X(16)  VALUE 'FORMAT          '.
           05  FILLER   PIC X(16)  VALUE 'FREE            '.
           05  FILLER   PIC X(16)  VALUE 'FROM            '.
           05  FILLER   PIC X(16)  VALUE 'FUNCTION        '.
           05  FILLER   PIC X(16)  VALUE 'GENERATE        '.
           05  FILLER   PIC X(16)  VALUE 'GET             '.
           05  FILLER   PIC X(16)  VALUE 'GIVING          '.
           05  FILLER   PIC X(16)  VALUE 'GLOBAL          '.
           05  FILLER   PIC X(16)  VALUE 'GO              '.
           05  FILLER   PIC X(16)  VALUE 'GOBACK          '.
           05  FILLER   PIC X(16)  VALUE 'GREATER         '.
           05  FILLER   PIC X(16)  VALUE 'GROUP           '.
           05  FILLER   PIC X(16)  VALUE 'HEADING         '.
           05  FILLER   PIC X(16)  VALUE 'HIGH-VALUE      '.
           05  FILLER   PIC X(16)  VALUE 'HIGH-VALUES     '.
           05  FILLER   PIC X(16)  VALUE 'I-O             '.
           05  FILLER   PIC X(16)  VALUE 'I-O-CONTROL     '.
           05  FILLER   PIC X(16)  VALUE 'ID              '.
           05  FILLER   PIC X(16)  VALUE 'IDENTIFICATION  '.
           05  FILLER   PIC X(16)  VALUE 'IF              '.
           05  FILLER   PIC X(16)  VALUE 'INCLUDE         '.
           05  FILLER   PIC X(16)  VALUE 'INDEX           '.
           05  FILLER   PIC X(16)  VALUE 'INDEX-1         '.
           05  FILLER   PIC X(16)  VALUE 'INDEX-2         '.
           05  FILLER   PIC X(16)  VALUE 'INDEX-3         '.
           05  FILLER   PIC X(16)  VALUE 'INDEX-4         '.
           05  FILLER   PIC X(16)  VALUE 'INDEX-5         '.
           05  FILLER   PIC X(16)  VALUE 'INDEX-6         '.
           05  FILLER   PIC X(16)  VALUE 'INDEX-7         '.
           05  FILLER   PIC X(16)  VALUE 'INDEX-8         '.
           05  FILLER   PIC X(16)  VALUE 'INDEX-9         '.
           05  FILLER   PIC X(16)  VALUE 'INDEXED         '.
           05  FILLER   PIC X(16)  VALUE 'INDICATE        '.
           05  FILLER   PIC X(16)  VALUE 'INITIAL         '.
           05  FILLER   PIC X(16)  VALUE 'INITIALIZE      '.
           05  FILLER   PIC X(16)  VALUE 'INITIATE        '.
           05  FILLER   PIC X(16)  VALUE 'INPUT           '.
           05  FILLER   PIC X(16)  VALUE 'INPUT-OUTPUT    '.
           05  FILLER   PIC X(16)  VALUE 'INSERT          '.
           05  FILLER   PIC X(16)  VALUE 'INSPECT         '.
           05  FILLER   PIC X(16)  VALUE 'INSTALLATION    '.
           05  FILLER   PIC X(16)  VALUE 'INTO            '.
           05  FILLER   PIC X(16)  VALUE 'INVALID         '.
           05  FILLER   PIC X(16)  VALUE 'IS              '.
           05  FILLER   PIC X(16)  VALUE 'JUST            '.
           05  FILLER   PIC X(16)  VALUE 'JUSTIFIED       '.
           05  FILLER   PIC X(16)  VALUE 'KANJI           '.
           05  FILLER   PIC X(16)  VALUE 'KEEP            '.
           05  FILLER   PIC X(16)  VALUE 'KEY             '.
           05  FILLER   PIC X(16)  VALUE 'LABEL           '.
           05  FILLER   PIC X(16)  VALUE 'LAST            '.
           05  FILLER   PIC X(16)  VALUE 'LD              '.
           05  FILLER   PIC X(16)  VALUE 'LEADING         '.
           05  FILLER   PIC X(16)  VALUE 'LEFT            '.
           05  FILLER   PIC X(16)  VALUE 'LENGTH          '.
           05  FILLER   PIC X(16)  VALUE 'LESS            '.
           05  FILLER   PIC X(16)  VALUE 'LIMIT           '.
           05  FILLER   PIC X(16)  VALUE 'LIMITS          '.
           05  FILLER   PIC X(16)  VALUE 'LINAGE          '.
           05  FILLER   PIC X(16)  VALUE 'LINAGE-COUNTER  '.
           05  FILLER   PIC X(16)  VALUE 'LINE            '.
           05  FILLER   PIC X(16)  VALUE 'LINE-COUNTER    '.
           05  FILLER   PIC X(16)  VALUE 'LINES           '.
           05  FILLER   PIC X(16)  VALUE 'LINKAGE         '.
           05  FILLER   PIC X(16)  VALUE 'LOCALLY         '.
           05  FILLER   PIC X(16)  VALUE 'LOCK            '.
           05  FILLER   PIC X(16)  VALUE 'LOW-VALUE       '.
           05  FILLER   PIC X(16)  VALUE 'LOW-VALUES      '.
           05  FILLER   PIC X(16)  VALUE 'MEMBER          '.
           05  FILLER   PIC X(16)  VALUE 'MEMORY          '.
           05  FILLER   PIC X(16)  VALUE 'MERGE           '.
           05  FILLER   PIC X(16)  VALUE 'MESSAGE         '.
           05  FILLER   PIC X(16)  VALUE 'MODE            '.
           05  FILLER   PIC X(16)  VALUE 'MODIFY          '.
           05  FILLER   PIC X(16)  VALUE 'MODULES         '.
           05  FILLER   PIC X(16)  VALUE 'MORE-LABELS     '.
           05  FILLER   PIC X(16)  VALUE 'MOVE            '.
           05  FILLER   PIC X(16)  VALUE 'MULTIPLE        '.
           05  FILLER   PIC X(16)  VALUE 'MULTIPLY        '.
           05  FILLER   PIC X(16)  VALUE 'NATIVE          '.
           05  FILLER   PIC X(16)  VALUE 'NEGATIVE        '.
           05  FILLER   PIC X(16)  VALUE 'NEXT            '.
           05  FILLER   PIC X(16)  VALUE 'NO              '.
           05  FILLER   PIC X(16)  VALUE 'NONE            '.
           05  FILLER   PIC X(16)  VALUE 'NOT             '.
           05  FILLER   PIC X(16)  VALUE 'NULL            '.
           05  FILLER   PIC X(16)  VALUE 'NULLS           '.
           05  FILLER   PIC X(16)  VALUE 'NUMBER          '.
           05  FILLER   PIC X(16)  VALUE 'NUMERIC         '.
           05  FILLER   PIC X(16)  VALUE 'NUMERIC-EDITED  '.
           05  FILLER   PIC X(16)  VALUE 'OBJECT-COMPUTER '.
           05  FILLER   PIC X(16)  VALUE 'OCCURS          '.
           05  FILLER   PIC X(16)  VALUE 'OF              '.
           05  FILLER   PIC X(16)  VALUE 'OFF             '.
           05  FILLER   PIC X(16)  VALUE 'OMITTED         '.
           05  FILLER   PIC X(16)  VALUE 'ON              '.
           05  FILLER   PIC X(16)  VALUE 'ONLY            '.
           05  FILLER   PIC X(16)  VALUE 'OPEN            '.
           05  FILLER   PIC X(16)  VALUE 'OPTIONAL        '.
           05  FILLER   PIC X(16)  VALUE 'OR              '.
           05  FILLER   PIC X(16)  VALUE 'ORDER           '.
           05  FILLER   PIC X(16)  VALUE 'ORGANIZATION    '.
           05  FILLER   PIC X(16)  VALUE 'OTHER           '.
           05  FILLER   PIC X(16)  VALUE 'OUTPUT          '.
           05  FILLER   PIC X(16)  VALUE 'OVERFLOW        '.
           05  FILLER   PIC X(16)  VALUE 'OWNER           '.
           05  FILLER   PIC X(16)  VALUE 'PACKED-DECIMAL  '.
           05  FILLER   PIC X(16)  VALUE 'PADDING         '.
           05  FILLER   PIC X(16)  VALUE 'PAGE            '.
           05  FILLER   PIC X(16)  VALUE 'PAGE-COUNTER    '.
           05  FILLER   PIC X(16)  VALUE 'PARAGRAPH       '.
           05  FILLER   PIC X(16)  VALUE 'PASSWORD        '.
           05  FILLER   PIC X(16)  VALUE 'PERFORM         '.
           05  FILLER   PIC X(16)  VALUE 'PF              '.
           05  FILLER   PIC X(16)  VALUE 'PH              '.
           05  FILLER   PIC X(16)  VALUE 'PIC             '.
           05  FILLER   PIC X(16)  VALUE 'PICTURE         '.
           05  FILLER   PIC X(16)  VALUE 'PLUS            '.
           05  FILLER   PIC X(16)  VALUE 'POINTER         '.
           05  FILLER   PIC X(16)  VALUE 'POSITION        '.
           05  FILLER   PIC X(16)  VALUE 'POSITIVE        '.
           05  FILLER   PIC X(16)  VALUE 'PRESENT         '.
           05  FILLER   PIC X(16)  VALUE 'PRINTING        '.
           05  FILLER   PIC X(16)  VALUE 'PRIOR           '.
           05  FILLER   PIC X(16)  VALUE 'PROCEDURE       '.
           05  FILLER   PIC X(16)  VALUE 'PROCEDURES      '.
           05  FILLER   PIC X(16)  VALUE 'PROCEED         '.
           05  FILLER   PIC X(16)  VALUE 'PROCESSING      '.
           05  FILLER   PIC X(16)  VALUE 'PROGRAM         '.
           05  FILLER   PIC X(16)  VALUE 'PROGRAM-ID      '.
           05  FILLER   PIC X(16)  VALUE 'PROTECTED       '.
           05  FILLER   PIC X(16)  VALUE 'PURGE           '.
           05  FILLER   PIC X(16)  VALUE 'QUEUE           '.
           05  FILLER   PIC X(16)  VALUE 'QUOTE           '.
           05  FILLER   PIC X(16)  VALUE 'QUOTES          '.
           05  FILLER   PIC X(16)  VALUE 'RANDOM          '.
           05  FILLER   PIC X(16)  VALUE 'RD              '.
           05  FILLER   PIC X(16)  VALUE 'READ            '.
           05  FILLER   PIC X(16)  VALUE 'READY           '.
           05  FILLER   PIC X(16)  VALUE 'REALM           '.
           05  FILLER   PIC X(16)  VALUE 'RECEIVE         '.
           05  FILLER   PIC X(16)  VALUE 'RECONNECT       '.
           05  FILLER   PIC X(16)  VALUE 'RECORD          '.
           05  FILLER   PIC X(16)  VALUE 'RECORD-NAME     '.
           05  FILLER   PIC X(16)  VALUE 'RECORDING       '.
           05  FILLER   PIC X(16)  VALUE 'RECORDS         '.
           05  FILLER   PIC X(16)  VALUE 'REDEFINES       '.
           05  FILLER   PIC X(16)  VALUE 'REEL            '.
           05  FILLER   PIC X(16)  VALUE 'REFERENCE       '.
           05  FILLER   PIC X(16)  VALUE 'REFERENCES      '.
           05  FILLER   PIC X(16)  VALUE 'RELATION        '.
           05  FILLER   PIC X(16)  VALUE 'RELATIVE        '.
           05  FILLER   PIC X(16)  VALUE 'RELEASE         '.
           05  FILLER   PIC X(16)  VALUE 'RELOAD          '.
           05  FILLER   PIC X(16)  VALUE 'REMAINDER       '.
           05  FILLER   PIC X(16)  VALUE 'REMOVAL         '.
           05  FILLER   PIC X(16)  VALUE 'RENAMES         '.
           05  FILLER   PIC X(16)  VALUE 'REPEATED        '.
           05  FILLER   PIC X(16)  VALUE 'REPLACE         '.
           05  FILLER   PIC X(16)  VALUE 'REPLACING       '.
           05  FILLER   PIC X(16)  VALUE 'REPORT          '.
           05  FILLER   PIC X(16)  VALUE 'REPORTING       '.
           05  FILLER   PIC X(16)  VALUE 'REPORTS         '.
           05  FILLER   PIC X(16)  VALUE 'RERUN           '.
           05  FILLER   PIC X(16)  VALUE 'RESERVE         '.
           05  FILLER   PIC X(16)  VALUE 'RESET           '.
           05  FILLER   PIC X(16)  VALUE 'RETAINING       '.
           05  FILLER   PIC X(16)  VALUE 'RETRIEVAL       '.
           05  FILLER   PIC X(16)  VALUE 'RETURN          '.
           05  FILLER   PIC X(16)  VALUE 'RETURN-CODE     '.
           05  FILLER   PIC X(16)  VALUE 'REVERSED        '.
           05  FILLER   PIC X(16)  VALUE 'REWIND          '.
           05  FILLER   PIC X(16)  VALUE 'REWRITE         '.
           05  FILLER   PIC X(16)  VALUE 'RF              '.
           05  FILLER   PIC X(16)  VALUE 'RH              '.
           05  FILLER   PIC X(16)  VALUE 'RIGHT           '.
           05  FILLER   PIC X(16)  VALUE 'ROLLBACK        '.
           05  FILLER   PIC X(16)  VALUE 'ROUNDED         '.
           05  FILLER   PIC X(16)  VALUE 'RUN             '.
           05  FILLER   PIC X(16)  VALUE 'SAME            '.
           05  FILLER   PIC X(16)  VALUE 'SD              '.
           05  FILLER   PIC X(16)  VALUE 'SEARCH          '.
           05  FILLER   PIC X(16)  VALUE 'SECTION         '.
           05  FILLER   PIC X(16)  VALUE 'SECURITY        '.
           05  FILLER   PIC X(16)  VALUE 'SEGMENT         '.
           05  FILLER   PIC X(16)  VALUE 'SEGMENT-LIMIT   '.
           05  FILLER   PIC X(16)  VALUE 'SELECT          '.
           05  FILLER   PIC X(16)  VALUE 'SEND            '.
           05  FILLER   PIC X(16)  VALUE 'SENTENCE        '.
           05  FILLER   PIC X(16)  VALUE 'SEPARATE        '.
           05  FILLER   PIC X(16)  VALUE 'SEQUENCE        '.
           05  FILLER   PIC X(16)  VALUE 'SEQUENTIAL      '.
           05  FILLER   PIC X(16)  VALUE 'SERVICE         '.
           05  FILLER   PIC X(16)  VALUE 'SESSION-ID      '.
           05  FILLER   PIC X(16)  VALUE 'SET             '.
           05  FILLER   PIC X(16)  VALUE 'SHARED          '.
           05  FILLER   PIC X(16)  VALUE 'SHIFT-IN        '.
           05  FILLER   PIC X(16)  VALUE 'SHIFT-OUT       '.
           05  FILLER   PIC X(16)  VALUE 'SIGN            '.
           05  FILLER   PIC X(16)  VALUE 'SIZE            '.
           05  FILLER   PIC X(16)  VALUE 'SKIP1           '.
           05  FILLER   PIC X(16)  VALUE 'SKIP2           '.
           05  FILLER   PIC X(16)  VALUE 'SKIP3           '.
           05  FILLER   PIC X(16)  VALUE 'SORT            '.
           05  FILLER   PIC X(16)  VALUE 'SORT-CONTROL    '.
           05  FILLER   PIC X(16)  VALUE 'SORT-CORE-SIZE  '.
           05  FILLER   PIC X(16)  VALUE 'SORT-FILE-SIZE  '.
           05  FILLER   PIC X(16)  VALUE 'SORT-MERGE      '.
           05  FILLER   PIC X(16)  VALUE 'SORT-MESSAGE    '.
           05  FILLER   PIC X(16)  VALUE 'SORT-MODE-SIZE  '.
           05  FILLER   PIC X(16)  VALUE 'SORT-RETURN     '.
           05  FILLER   PIC X(16)  VALUE 'SOURCE          '.
           05  FILLER   PIC X(16)  VALUE 'SOURCE-COMPUTER '.
           05  FILLER   PIC X(16)  VALUE 'SPACE           '.
           05  FILLER   PIC X(16)  VALUE 'SPACES          '.
           05  FILLER   PIC X(16)  VALUE 'SPECIAL-NAMES   '.
           05  FILLER   PIC X(16)  VALUE 'STANDARD        '.
           05  FILLER   PIC X(16)  VALUE 'STANDARD-1      '.
           05  FILLER   PIC X(16)  VALUE 'STANDARD-2      '.
           05  FILLER   PIC X(16)  VALUE 'STANDARD-3      '.
           05  FILLER   PIC X(16)  VALUE 'STANDARD-4      '.
           05  FILLER   PIC X(16)  VALUE 'START           '.
           05  FILLER   PIC X(16)  VALUE 'STATUS          '.
           05  FILLER   PIC X(16)  VALUE 'STOP            '.
           05  FILLER   PIC X(16)  VALUE 'STORE           '.
           05  FILLER   PIC X(16)  VALUE 'STRING          '.
           05  FILLER   PIC X(16)  VALUE 'SUB-QUEUE-1     '.
           05  FILLER   PIC X(16)  VALUE 'SUB-QUEUE-2     '.
           05  FILLER   PIC X(16)  VALUE 'SUB-QUEUE-3     '.
           05  FILLER   PIC X(16)  VALUE 'SUB-SCHEMA      '.
           05  FILLER   PIC X(16)  VALUE 'SUBTRACT        '.
           05  FILLER   PIC X(16)  VALUE 'SUM             '.
           05  FILLER   PIC X(16)  VALUE 'SUPPRESS        '.
           05  FILLER   PIC X(16)  VALUE 'SYMBOLIC        '.
           05  FILLER   PIC X(16)  VALUE 'SYNC            '.
           05  FILLER   PIC X(16)  VALUE 'SYNCHRONIZED    '.
           05  FILLER   PIC X(16)  VALUE 'TABLE           '.
           05  FILLER   PIC X(16)  VALUE 'TALLY           '.
           05  FILLER   PIC X(16)  VALUE 'TALLYING        '.
           05  FILLER   PIC X(16)  VALUE 'TAPE            '.
           05  FILLER   PIC X(16)  VALUE 'TENANT          '.
           05  FILLER   PIC X(16)  VALUE 'TERMINAL        '.
           05  FILLER   PIC X(16)  VALUE 'TERMINATE       '.
           05  FILLER   PIC X(16)  VALUE 'TEST            '.
           05  FILLER   PIC X(16)  VALUE 'TEXT            '.
           05  FILLER   PIC X(16)  VALUE 'THAN            '.
           05  FILLER   PIC X(16)  VALUE 'THEN            '.
           05  FILLER   PIC X(16)  VALUE 'THROUGH         '.
           05  FILLER   PIC X(16)  VALUE 'THRU            '.
           05  FILLER   PIC X(16)  VALUE 'TIME            '.
           05  FILLER   PIC X(16)  VALUE 'TIMES           '.
           05  FILLER   PIC X(16)  VALUE 'TITLE           '.
           05  FILLER   PIC X(16)  VALUE 'TO              '.
           05  FILLER   PIC X(16)  VALUE 'TOP             '.
           05  FILLER   PIC X(16)  VALUE 'TRACE           '.
           05  FILLER   PIC X(16)  VALUE 'TRAILING        '.
           05  FILLER   PIC X(16)  VALUE 'TRANSCEIVE      '.
           05  FILLER   PIC X(16)  VALUE 'TRUE            '.
           05  FILLER   PIC X(16)  VALUE 'TYPE            '.
           05  FILLER   PIC X(16)  VALUE 'UNEQUAL         '.
           05  FILLER   PIC X(16)  VALUE 'UNIT            '.
           05  FILLER   PIC X(16)  VALUE 'UNSTRING        '.
           05  FILLER   PIC X(16)  VALUE 'UNTIL           '.
           05  FILLER   PIC X(16)  VALUE 'UP              '.
           05  FILLER   PIC X(16)  VALUE 'UPDATE          '.
           05  FILLER   PIC X(16)  VALUE 'UPON            '.
           05  FILLER   PIC X(16)  VALUE 'USAGE           '.
           05  FILLER   PIC X(16)  VALUE 'USAGE-MODE      '.
           05  FILLER   PIC X(16)  VALUE 'USE             '.
           05  FILLER   PIC X(16)  VALUE 'USING           '.
           05  FILLER   PIC X(16)  VALUE 'VALID           '.
           05  FILLER   PIC X(16)  VALUE 'VALIDATE        '.
           05  FILLER   PIC X(16)  VALUE 'VALUE           '.
           05  FILLER   PIC X(16)  VALUE 'VALUES          '.
           05  FILLER   PIC X(16)  VALUE 'VARYING         '.
           05  FILLER   PIC X(16)  VALUE 'WAIT            '.
           05  FILLER   PIC X(16)  VALUE 'WHEN            '.
           05  FILLER   PIC X(16)  VALUE 'WHEN-COMPILED   '.
           05  FILLER   PIC X(16)  VALUE 'WITH            '.
           05  FILLER   PIC X(16)  VALUE 'WITHIN          '.
           05  FILLER   PIC X(16)  VALUE 'WORDS           '.
           05  FILLER   PIC X(16)  VALUE 'WORKING-STORAGE '.
           05  FILLER   PIC X(16)  VALUE 'WRITE           '.
           05  FILLER   PIC X(16)  VALUE 'WRITE-ONLY      '.
           05  FILLER   PIC X(16)  VALUE 'ZERO            '.
           05  FILLER   PIC X(16)  VALUE 'ZEROES          '.
           05  FILLER   PIC X(16)  VALUE 'ZEROS           '.

       01  560-RESERVED-WORD-TABLE     REDEFINES 550-RESERVED-WORD-DATA.
           05  560-RESERVED-WORD           OCCURS 503 TIMES
                   ASCENDING KEY IS 560-RESERVED-WORD
                   INDEXED BY CW           PIC X(16).
       EJECT
      ****************************************************************
      *    PROGRAM LINES TABLE                                       *
      ****************************************************************

       01  580-PROGRAM-LINE-TABLE.
           05  580-PROGRAM-LINE            OCCURS 10000 TIMES
                                           INDEXED BY PL.
               10  580-LINE-TYPE           PIC X(01)   VALUE SPACE.
               10  580-VERTICAL-ACTION     PIC X(01)   VALUE SPACE.
               10  580-COBOL-DATA.
                   15  580-INDICATOR-AREA  PIC X(01)   VALUE SPACE.
                   15  FILLER              PIC X(65)   VALUE SPACES.
       EJECT
      ****************************************************************
      *    600- PROGRAM MESSAGES                                     *
      ****************************************************************

       01  600-PROGRAM-MESSAGES.
           05  FILLER                  PIC X(32)   VALUE
              '***** 600-PROGRAM-MESSAGES *****'.
       SKIP1
           05  600-EXEC-START-MSG      PIC X(54)   VALUE
              'CB2ALIGN-0001  CONVERT TO COBOL II & BEAUTIFY - PASS 1'.
       SKIP1
           05  600-COMPILE-INFO-MSG.
               10  FILLER              PIC X(30)   VALUE
                  'CB2ALIGN-0002  COMPILE DATE = '.
               10  600-COMPILE-DATE    PIC X(08).
               10  FILLER              PIC X(09)   VALUE ', TIME = '.
               10  600-COMPILE-TIME    PIC X(08).
               10  FILLER              PIC X(05)   VALUE SPACES.
       SKIP1
           05  600-CURRENT-RUN-MSG.
               10  FILLER              PIC X(30)   VALUE
                  'CB2ALIGN-0003  CURRENT DATE = '.
               10  600-CURRENT-DATE    PIC X(08)   VALUE SPACES.
               10  FILLER              PIC X(09)   VALUE ', TIME = '.
               10  600-RUN-TIME.
                   15  600-RUN-HOUR    PIC 9(02).
                   15  FILLER          PIC X(01)   VALUE ':'.
                   15  600-RUN-MIN     PIC 9(02).
                   15  FILLER          PIC X(01)   VALUE ':'.
                   15  600-RUN-SEC     PIC 9(02).
               10  FILLER              PIC X(01)   VALUE SPACES.
       SKIP1
           05  600-TABLE-FULL-MSG      PIC X(54)   VALUE
              'CB2ALIGN-9999  TABLE OF PROGRAM LINES EXCEEDED.'.
       SKIP1
           05  600-TOTAL-MESSAGE.
               10  FILLER              PIC X(24)   VALUE
                  'CB2ALIGN-9999  PROGRAM ('.
               10  600-DISPLAY-PGM     PIC X(08).
               10  FILLER              PIC X(02)   VALUE ') '.
               10  600-TOTAL-ID        PIC X(36)   VALUE SPACES.
               10  600-DISPLAY-TOTAL   PIC ZZZ,ZZ9.
           05  600-TOTAL-SOURCE-MSG    PIC X(40)   VALUE
              'COBOL SOURCE PROGRAM RECORDS READ'.
           05  600-OLD-LINES-MSG       PIC X(40)   VALUE
              'OLD SOURCE PROGRAM LINES DROPPED'.
           05  600-NEW-LINES-MSG       PIC X(40)   VALUE
              'NEW SOURCE PROGRAM LINES ADDED'.
           05  600-OUT-LINES-MSG       PIC X(40)   VALUE
              'OUTPUT SOURCE-PROGRAM LINES'.
       EJECT
           05  600-TABLE-OVERFLOW-MSG.
               10  FILLER              PIC X(14)   VALUE
                  '-S  PARAGRAPH('.
               10  600-PARAGRAPH-NAME  PIC X(30)   VALUE SPACES.
               10  FILLER              PIC X(24)   VALUE
                  ') NOT LOADED, MORE THAN '.
               10  600-MAX-PARAGRAPHS  PIC ZZZ9.
               10  FILLER              PIC X(28)   VALUE
                  ' PARAGRAPH NAMES ARE IN USE.'.
       SKIP1
           05  600-PROGRAM-ID-MSG.
               10  FILLER              PIC X(50)   VALUE
                  '-S  NO PROGRAM-ID FOUND IN INPUT FILE.'.
       SKIP1
           05  600-ID-DIV-HEADER           PIC X(40)   VALUE
               ' IDENTIFICATION DIVISION.'.
       SKIP1
           05  600-BLANK-LINE          PIC X(02)   VALUE SPACES.
           05  600-ALIGNTARGET-MSG     PIC X(60)   VALUE
              'ALIGNTARGET   - ALIGNS "TO" TARGETS TO COLUMN 40.'.
           05  600-NOALIGNTARGET-MSG    PIC X(60)   VALUE
              'NOALIGNTARGET - NO COLUMN 40 TARGET ALIGNMENT.'.
           05  600-PARACOMMENT-MSG     PIC X(60)   VALUE
              'PARACOMMENT   - BUILDS PARAGRAPH COMMENT HEADERS.'.
           05  600-NOPARACOMMENT-MSG    PIC X(60)   VALUE
              'NOPARACOMMENT - DOES NOT BUILD COMMENT HEADERS.'.
           05  600-INSERT-NOHANDLE-MSG  PIC X(60)   VALUE
              'NOHANDLE      - INSERTS CICS "NOHANDLE" OPTIONS.'.
       EJECT
      ****************************************************************
      *    700- CODE TO BE INSERTED INTO OUTPUT PROGRAM              *
      ****************************************************************

       01  700-COBOL-INSERT-DATA.
           05  FILLER                      PIC X(32)   VALUE
              '**** 700-COBOL-INSERT-DATA *****'.
           05  700-DATETIME-LINE-01        PIC X(64)   VALUE 'EJECT '.
           05  700-DATETIME-LINE-02.
               10  FILLER                  PIC X(64)   VALUE
                  '01  CBL2-ANSI85-CONVERSION-DATA.'.
           05  700-DATETIME-LINE-03.
               10  FILLER                  PIC X(64)   VALUE
                  '    05  CBL2-ANSI85-WHEN-COMPILED. '.
           05  700-DATETIME-LINE-04.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  CBL2-ANSI85-COMP-DATE  '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(08)   VALUE SPACES.'.
           05  700-DATETIME-LINE-05.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  CBL2-ANSI85-COMP-TIME  '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(12)   VALUE SPACES.'.
           05  700-DATETIME-LINE-06.
               10  FILLER                  PIC X(64)   VALUE
                  '    05  CBL2-COMPILED.             '.
           05  700-DATETIME-LINE-07.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  CBL2-ANSI74-COMP-TIME  '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(08)   VALUE SPACES.'.
           05  700-DATETIME-LINE-08.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  CBL2-ANSI74-COMP-DATE  '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(12)   VALUE SPACES.'.
           05  700-DATETIME-LINE-09.
               10  FILLER                  PIC X(64)   VALUE
                  '    05  CBL2-ANSI85-DATE.          '.
           05  700-DATETIME-LINE-10.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  CBL2-ANSI85-DATE-YY    '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(02)   VALUE ZEROS. '.
           05  700-DATETIME-LINE-11.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  CBL2-ANSI85-DATE-MM    '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(02)   VALUE ZEROS. '.
           05  700-DATETIME-LINE-12.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  CBL2-ANSI85-DATE-DD    '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(02)   VALUE ZEROS. '.
           05  700-DATETIME-LINE-13.
               10  FILLER                  PIC X(64)   VALUE
                  '    05  CBL2-CURDATE.              '.
           05  700-DATETIME-LINE-14.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  CBL2-ANSI74-DATE-MM    '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(02)   VALUE SPACES.'.
           05  700-DATETIME-LINE-15.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  FILLER                 '.
               10  FILLER                  PIC X(18)   VALUE
                  'PIC X(01)   VALUE '.
               10  FILLER                  PIC X(01)   VALUE QUOTE.
               10  FILLER                  PIC X(01)   VALUE '/'.
               10  FILLER                  PIC X(01)   VALUE QUOTE.
               10  FILLER                  PIC X(07)   VALUE '.  '.
           05  700-DATETIME-LINE-16.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  CBL2-ANSI74-DATE-DD    '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(02)   VALUE SPACES.'.
           05  700-DATETIME-LINE-17.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  FILLER                 '.
               10  FILLER                  PIC X(18)   VALUE
                  'PIC X(01)   VALUE '.
               10  FILLER                  PIC X(01)   VALUE QUOTE.
               10  FILLER                  PIC X(01)   VALUE '/'.
               10  FILLER                  PIC X(01)   VALUE QUOTE.
               10  FILLER                  PIC X(07)   VALUE '.  '.
           05  700-DATETIME-LINE-18.
               10  FILLER                  PIC X(36)   VALUE
                  '        10  CBL2-ANSI74-DATE-YY    '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(02)   VALUE SPACES.'.
           05  700-DATETIME-LINE-19.
               10  FILLER                  PIC X(36)   VALUE
                  '    05  CBL2-ANSI85-TIME           '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(08)   VALUE SPACES.'.
           05  700-DATETIME-LINE-20.
               10  FILLER                  PIC X(36)   VALUE
                  '    05  CBL2-CURTOD                '.
               10  FILLER                  PIC X(28)   VALUE
                  'PIC X(06)   VALUE SPACES.'.
           05  700-SET-ADDR-LINE-1.
               10  FILLER                  PIC X(05)   VALUE SPACES.
               10  FILLER                  PIC X(15)   VALUE
                  'SET ADDRESS OF '.
               10  700-DSECT-NAME          PIC X(30)   VALUE SPACES.
               10  FILLER                  PIC X(16)   VALUE SPACES.
           05  700-SET-ADDR-LINE-2.
               10  FILLER                  PIC X(05)   VALUE SPACES.
               10  FILLER                  PIC X(15)   VALUE
                  '            TO '.
               10  700-POINTER-NAME        PIC X(31)   VALUE SPACES.
               10  FILLER                  PIC X(15)   VALUE SPACES.
       EJECT
      ****************************************************************
      *    800- GENERAL PROGRAM WORKAREAS                            *
      ****************************************************************

       01  800-GENERAL-WORKAREAS.
           05  FILLER                      PIC X(32)   VALUE
              '******** 800-WORK-AREAS ********'.
           05  800-WORK-LEVEL              PIC S9(04)  COMP.
           05  800-SUB                     PIC S9(04)  COMP.
           05  800-SUB2                    PIC S9(04)  COMP.
           05  800-I                       PIC S9(04)  COMP.
           05  800-J                       PIC S9(04)  COMP.
           05  800-C1                      PIC S9(04)  COMP.
           05  800-C2                      PIC S9(04)  COMP.
           05  800-C3                      PIC S9(04)  COMP.
           05  800-HIGH-USED-PARAGRAPH     PIC S9(04)  COMP VALUE ZERO.
           05  800-NEXT-OPEN-PARAGRAPH     PIC S9(04)  COMP VALUE +1.
           05  800-ID-DIV-LINE             PIC 9(5)    COMP-3 VALUE 0.
           05  800-ENV-DIV-LINE            PIC 9(5)    COMP-3 VALUE 0.
           05  800-CFG-SECT-LINE           PIC 9(5)    COMP-3 VALUE 0.
           05  800-IO-SECT-LINE            PIC 9(5)    COMP-3 VALUE 0.
           05  800-DATA-DIV-LINE           PIC 9(5)    COMP-3 VALUE 0.
           05  800-FILE-SECT-LINE          PIC 9(5)    COMP-3 VALUE 0.
           05  800-WS-SECT-LINE            PIC 9(5)    COMP-3 VALUE 0.
           05  800-LINK-SECT-LINE          PIC 9(5)    COMP-3 VALUE 0.
           05  800-PROC-DIV-LINE           PIC 9(5)    COMP-3 VALUE 0.
           05  800-CBL2-ID-LINE            PIC 9(5)    COMP-3 VALUE 0.
           05  800-CBL2-WS-LINE            PIC 9(5)    COMP-3 VALUE 0.
           05  800-CBL2-WHEN-COMP-LINE     PIC 9(5)    COMP-3 VALUE 0.
           05  800-CBL2-CURDATE-LINE       PIC 9(5)    COMP-3 VALUE 0.
           05  800-CBL2-CURTIME-LINE       PIC 9(5)    COMP-3 VALUE 0.
           05  800-DUMP-X                  PIC X(02)   VALUE SPACES.
           05  800-DUMP                REDEFINES 800-DUMP-X
                                           PIC S9(3)   COMP-3.
           05  800-PROGRAM-ID              PIC X(08)   VALUE '????????'.
           05  800-COMPILATION-DATE.
               10  800-COMPILE-DATE.
                   15  800-COMPILE-MM      PIC X(02).
                   15  FILLER              PIC X(01).
                   15  800-COMPILE-DD      PIC X(02).
                   15  FILLER              PIC X(01).
                   15  800-COMPILE-YY      PIC X(02).
               10  800-COMPILE-TIME        PIC X(12).
           05  800-CURRENT-DATE.
               10  800-CURRENT-MM          PIC X(02).
               10  FILLER                  PIC X(01)   VALUE '/'.
               10  800-CURRENT-DD          PIC X(02).
               10  FILLER                  PIC X(01)   VALUE '/'.
               10  800-CURRENT-YY          PIC X(02).
           05  800-SYSTEM-DATE.
               10  800-SYSDATE-YY          PIC 9(02).
               10  800-SYSDATE-MM          PIC 9(02).
               10  800-SYSDATE-DD          PIC 9(02).
           05  800-CURRENT-TIME.
               10  800-RUN-HOUR            PIC 9(02).
               10  800-RUN-MIN             PIC 9(02).
               10  800-RUN-SEC             PIC 9(02).
               10  800-RUN-HSEC            PIC 9(02).
           05  800-NEW-LINE-X.
               10  800-NEW-LINE-N          PIC 9(05)   VALUE ZEROS.
               10  FILLER                  PIC X(01)   VALUE SPACE.
           05  800-NEW-CICS-PTR.
               10  FILLER                  PIC X(05)   VALUE '-PTR-'.
               10  800-NEW-CICS-PTR-NBR    PIC 9(03)   VALUE ZEROS.
           05  800-CURRENT-CICS-PTR        PIC X(30)   VALUE '????????'.
           05  800-WORK-TOKEN-16           PIC X(16)   VALUE SPACES.
           05  800-HOLD-80-BYTES           PIC X(80)   VALUE SPACES.
           05  FILLER                      PIC X(80)   VALUE SPACES.
       SKIP1
       01  810-COMPRESS-WORK-AREA.
           05  810-COMPRESS-WORK-1.
               10  810-SOURCE-CHAR         OCCURS 65 TIMES
                                           INDEXED BY 810-SI
                                           PIC X(01).
           05  FILLER                      PIC X(15)   VALUE SPACES.
           05  810-COMPRESS-WORK-2.
               10  810-TARGET-CHAR         OCCURS 65 TIMES
                                           INDEXED BY 810-DI
                                           PIC X(01).
           05  FILLER                      PIC X(15)   VALUE SPACES.
       SKIP1
       01  820-TARGETS-WORK-AREA.
           05  820-HOLD-RECORD             PIC X(80)   VALUE SPACES.
           05  820-WORK-RECORD             PIC X(80)   VALUE SPACES.
           05  820-ALIGNMENT-COLUMN        PIC S9(4)   COMP VALUE ZERO.
           05  820-BASE                    PIC S9(4)   COMP VALUE ZERO.
           05  820-COUNT                   PIC S9(4)   COMP VALUE ZERO.
           05  820-SHIFT                   PIC S9(4)   COMP VALUE ZERO.
           05  820-MOVE-FLAG               PIC X(01)   VALUE 'N'.
               88  88-820-MOVE-IS-NOT-ACTIVE           VALUE 'N'.
               88  88-820-MOVE-IS-ACTIVE               VALUE 'Y'.
           05  820-MOVE-TO-FLAG            PIC X(01)   VALUE 'N'.
               88  88-820-MOVE-TO-IS-NOT-ACTIVE        VALUE 'N'.
               88  88-820-MOVE-TO-IS-ACTIVE            VALUE 'Y'.
           05  820-USING-FLAG              PIC X(01)   VALUE 'N'.
               88  88-820-USING-IS-NOT-ACTIVE          VALUE 'N'.
               88  88-820-USING-IS-ACTIVE              VALUE 'Y'.
           05  820-TARGET-FLAG             PIC X(01)   VALUE 'N'.
               88  88-820-BYPASS-TARGET-FIX            VALUE 'N'.
               88  88-820-FIX-TARGETS                  VALUE 'Y'.
       SKIP1
       01  830-SET-ADDRESS-WORK-LINE.
           05  FILLER                      PIC X(07)   VALUE '00000  '.
           05  830-LITERAL-DOT             PIC X(01)   VALUE '.'.
           05  830-DSECT-NAME              PIC X(30)   VALUE SPACES.
           05  830-POINTER-NAME            PIC X(30)   VALUE SPACES.
           05  830-PERIOD                  PIC X(01)   VALUE SPACES.
           05  FILLER                      PIC X(11)   VALUE SPACES.

       01  830-WORK-LINE-2 REDEFINES 830-SET-ADDRESS-WORK-LINE.
           05  FILLER                      PIC X(06).
           05  830-TABLED-LINE             PIC X(66).
           05  FILLER                      PIC X(08).
       SKIP3
      ****************************************************************
      *    E N D   O F   W O R K I N G - S T O R A G E               *
      ****************************************************************

       01  999-END-CORE-ID                 PIC X(32)   VALUE
              'CB2ALIGN END OF WORKING-STORAGE'.
       EJECT
      ****************************************************************
      *    P R O C E D U R E   D I V I S I O N                       *
      ****************************************************************

       PROCEDURE DIVISION.

       0000-MAINLINE.

           PERFORM 1000-INITIALIZE-PROGRAM.

           PERFORM 2000-ANALYZE-COBOL-PROGRAM
               UNTIL 88-100-ALL-TOKENS-PROCESSED.

           PERFORM 4000-CLEAN-UP-TABLE.

           PERFORM 5000-WRITE-COBOL-PROGRAM.

           PERFORM 6000-TERMINATE-PROGRAM.

           GOBACK.
       EJECT
      ****************************************************************
      *    I N I T I A L I Z E   P R O G R A M                       *
      ****************************************************************

       1000-INITIALIZE-PROGRAM.

           PERFORM 1100-DISPLAY-START-MESSAGES.

           PERFORM 1200-OPEN-THE-FILES.

           PERFORM 1300-INITIALIZE-TABLES.

           PERFORM 1400-GET-RUNTIME-PARMS.
       SKIP3
      ****************************************************************
      *    D I S P L A Y   S T A R T   M E S S A G E S .             *
      ****************************************************************

       1100-DISPLAY-START-MESSAGES.

           MOVE WHEN-COMPILED          TO 800-COMPILATION-DATE.
           ACCEPT 800-SYSTEM-DATE      FROM DATE.
           ACCEPT 800-CURRENT-TIME     FROM TIME.
           DISPLAY 600-EXEC-START-MSG.

           MOVE 800-COMPILE-DATE       TO 600-COMPILE-DATE.
           MOVE 800-COMPILE-TIME       TO 600-COMPILE-TIME.
           DISPLAY 600-COMPILE-INFO-MSG.

           MOVE 800-SYSDATE-MM         TO 800-CURRENT-MM.
           MOVE 800-SYSDATE-DD         TO 800-CURRENT-DD.
           MOVE 800-SYSDATE-YY         TO 800-CURRENT-YY.
           MOVE 800-CURRENT-DATE       TO 600-CURRENT-DATE.
           MOVE 800-RUN-HOUR           TO 600-RUN-HOUR.
           MOVE 800-RUN-MIN            TO 600-RUN-MIN.
           MOVE 800-RUN-SEC            TO 600-RUN-SEC.
           DISPLAY 600-CURRENT-RUN-MSG.
       EJECT
      ****************************************************************
      *    O P E N   T H E   F I L E S .                             *
      ****************************************************************

       1200-OPEN-THE-FILES.

           OPEN INPUT SYS001-COBOL-FILE
               OUTPUT SYS201-PRINT-FILE.
       SKIP3
      ****************************************************************
      *    INITIALIZE THE TABLES.                                    *
      ****************************************************************

       1300-INITIALIZE-TABLES.

           SET 88-210-TOKEN-IS-SOF TO TRUE.
           INITIALIZE 580-PROGRAM-LINE-TABLE.
       EJECT
      ****************************************************************
      *    GET THE RUN-TIME PARAMETERS FROM THE 'SYSIN' CONTROL CARD.*
      ****************************************************************

       1400-GET-RUNTIME-PARMS.

           ACCEPT 290-RUN-TIME-PARAMETER-CARD FROM SYSIN.

           PERFORM VARYING 800-I FROM 1 BY 1
                   UNTIL   800-I IS GREATER THAN 300-COMP-65
               IF 290-RUNTIME-PARMS (800-I:6) EQUAL ' ALIGN'
               OR 290-RUNTIME-PARMS (800-I:6) EQUAL ',ALIGN'
                   SET 88-100-ALIGN-TARGET TO TRUE
               END-IF
               IF 290-RUNTIME-PARMS (800-I:5) EQUAL 'NOALI'
                   SET 88-100-NO-ALIGN-TARGET TO TRUE
               END-IF
               IF 290-RUNTIME-PARMS (800-I:5) EQUAL ' PARA'
               OR 290-RUNTIME-PARMS (800-I:5) EQUAL ',PARA'
                   SET 88-100-BUILD-PARA-COMMENT TO TRUE
               END-IF
               IF 290-RUNTIME-PARMS (800-I:5) EQUAL 'NOPAR'
                   SET 88-100-NO-PARA-COMMENT TO TRUE
               END-IF
               IF 290-RUNTIME-PARMS (800-I:5) EQUAL 'NOHAN'
                   SET 88-100-INSERT-NOHANDLE TO TRUE
               END-IF
           END-PERFORM.

           DISPLAY 600-BLANK-LINE.
           IF 88-100-BUILD-PARA-COMMENT
               DISPLAY 600-PARACOMMENT-MSG
           ELSE
               DISPLAY 600-NOPARACOMMENT-MSG.

           IF 88-100-ALIGN-TARGET
               DISPLAY 600-ALIGNTARGET-MSG
           ELSE
               DISPLAY 600-NOALIGNTARGET-MSG.

           IF 88-100-INSERT-NOHANDLE
               DISPLAY 600-INSERT-NOHANDLE-MSG.

           DISPLAY 600-BLANK-LINE.
       EJECT
      ****************************************************************
      *    ANALYZE THE COBOL PROGRAM, ONE TOKEN AT A TIME.           *
      ****************************************************************

       2000-ANALYZE-COBOL-PROGRAM.

           PERFORM 2100-GET-NEXT-TOKEN.

           PERFORM 2200-ANALYZE-1-TOKEN.

           IF 88-210-TOKEN-IS-EOL
               PERFORM 2300-LOAD-1-COBOL-LINE.
       EJECT
      ****************************************************************
      *    GET THE NEXT COBOL WORD (TOKEN) FROM THE INPUT FILE.      *
      ****************************************************************

       2100-GET-NEXT-TOKEN.

           IF 88-210-TOKEN-IS-EOL
               NEXT SENTENCE
           ELSE
               MOVE 230-3RD-TOKEN-RECORD
                                       TO 240-4TH-TOKEN-RECORD
               MOVE 220-LAST-TOKEN-RECORD
                                       TO 230-3RD-TOKEN-RECORD
               MOVE 210-TOKEN-RECORD   TO 220-LAST-TOKEN-RECORD.

           IF 88-220-TOKEN-WAS-SOF
           OR 88-210-TOKEN-IS-EOL
               PERFORM 2110-GET-NEXT-COBOL-RECORD
               PERFORM 2120-INITIALIZE-SCAN-PARMS
           ELSE
               MOVE 300-COMP-1         TO 800-SUB2
               MOVE ZERO               TO 210-TOKEN-LENGTH
               MOVE SPACES             TO 210-TOKEN-VALUE.

           MOVE ZERO                   TO 400-TOKEN-LETTERS
                                          400-TOKEN-NUMBERS
                                          400-TOKEN-HYPHENS.

           PERFORM UNTIL 200-SOURCE-CHAR (800-SUB) GREATER THAN SPACE
                      OR 800-SUB IS GREATER THAN 300-LINE-SCAN-LENGTH
               ADD 300-COMP-1          TO 800-SUB
           END-PERFORM.
           MOVE 800-SUB                TO 210-TOKEN-START.

           IF 800-SUB IS LESS THAN 300-COMP-5
               SET 88-210-TOKEN-IS-IN-AREA-A TO TRUE
           ELSE
               SET 88-210-TOKEN-IS-IN-AREA-B TO TRUE.

           IF 88-100-ALL-TOKENS-PROCESSED
               SET 88-210-TOKEN-IS-EOF TO TRUE
           ELSE
               IF 800-SUB IS GREATER THAN 300-LINE-SCAN-LENGTH
                   SET 88-210-TOKEN-IS-EOL TO TRUE
               ELSE
                   SET 88-210-TOKEN-IS-UNKNOWN TO TRUE
                   SET 88-100-START-OF-TOKEN   TO TRUE
                   PERFORM 2130-BUILD-ONE-TOKEN
                       UNTIL 88-100-END-OF-TOKEN
                          OR 800-SUB GREATER THAN 300-LINE-SCAN-LENGTH.

           IF 88-210-TOKEN-IS-UNKNOWN
               PERFORM 2140-IDENTIFY-TOKEN-TYPE.
       EJECT
      ****************************************************************
      *    GET THE NEXT COBOL SOURCE PROGRAM LINE.                   *
      ****************************************************************

       2110-GET-NEXT-COBOL-RECORD.

           READ SYS001-COBOL-FILE INTO 200-COBOL-RECORD
               AT END
                   SET 88-100-ALL-TOKENS-PROCESSED TO TRUE
               NOT AT END
                   SET 88-100-NORMAL-PRINT TO TRUE
                   ADD 300-ONE         TO 400-COBOL-LINE-COUNT
                   MOVE 400-COBOL-LINE-COUNT
                                       TO 210-LINE-NUMBER
                   IF 200-INDICATOR-AREA EQUAL SPACE
                       IF 88-210-PROCEDURE-DIVISION
                           PERFORM 2111-COMPRESS-CODE-LINE
                       ELSE
                           IF 88-210-DATA-DIVISION
                               PERFORM 2112-COMPRESS-PIC-LINE
                           ELSE
                               PERFORM 2113-EXPAND-A-LINE
                           END-IF
                       END-IF
                   ELSE
                       IF 88-200-EJECT-COMMENT
                           MOVE SPACE  TO 200-INDICATOR-AREA
                           MOVE 300-EJECT
                                       TO 200-SOURCE-CODE
                       END-IF
                   END-IF
           END-READ.
       EJECT
      ****************************************************************
      *    BEAUTIFY A PROCEDURE DIVISION LINE.                       *
      ****************************************************************

       2111-COMPRESS-CODE-LINE.

           PERFORM 2111-10-SHIFT-CODE-LEFT.

           IF 88-100-ALIGN-TARGET
               PERFORM 2111-20-ALIGN-MOVE-TARGETS.

           IF 88-100-CICS-EXEC-FOUND
               PERFORM 2111-30-EDIT-CICS-CALL.
       EJECT
      ****************************************************************
      *    COMPRESS A PROCEDURE DIVISION LINE, REMOVING COMMAS.      *
      *    AFTER FIRST CLEANING UP SOME FIGURATIVE CONSTANTS.        *
      ****************************************************************

       2111-10-SHIFT-CODE-LEFT.

           INSPECT 200-SOURCE-CODE REPLACING ALL ',' BY SPACE.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           PERFORM VARYING 800-C1 FROM 300-COMP-4 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF 200-SOURCE-CODE (800-C1 : 6) EQUAL ' 0    '
                   MOVE ' ZERO '       TO 200-SOURCE-CODE (800-C1 : 6)
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 6) EQUAL ' +0   '
                   MOVE ' ZERO '       TO 200-SOURCE-CODE (800-C1 : 6)
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 8) EQUAL ' ZEROES '
                   MOVE ' ZEROS  '     TO 200-SOURCE-CODE (800-C1 : 8)
               END-IF
           END-PERFORM.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE 300-COMP-1             TO 800-C1 800-C2 800-C3.
           PERFORM VARYING 800-C1 FROM 300-COMP-4 BY 300-COMP-1
                   UNTIL 200-SOURCE-CHAR (800-C1) NOT EQUAL SPACE
                      OR 800-C1 IS GREATER THAN 300-COMP-63
           END-PERFORM.
           MOVE 800-C1                 TO 800-C2.

           IF 88-100-CICS-EXEC-FOUND
               COMPUTE 800-C1 EQUAL 400-CICS-EXEC-POS + 1
               IF 800-C1 IS LESS THAN 800-C2
                   MOVE 800-C1         TO 800-C2.

           COMPUTE 800-C3 EQUAL 300-COMP-65 - 800-C2 + 300-COMP-1.
           MOVE 200-SOURCE-CODE (800-C2 : 800-C3)
                                       TO 810-COMPRESS-WORK-1.
           MOVE SPACES                 TO 810-COMPRESS-WORK-2.
           PERFORM 8300-COMPRESS-DATA-LINE.
           MOVE 810-COMPRESS-WORK-2
               TO 200-SOURCE-CODE (800-C2 : 800-C3).

           IF  800-C2 GREATER THAN 300-COMP-5
           AND 800-C2 IS LESS THAN 300-COMP-33
           AND 200-AREA-A EQUAL TO SPACES
               PERFORM 8400-SHIFT-STRING-RIGHT
                   UNTIL 800-C2 IS EQUAL TO 09 OR 13 OR 17 OR 21
                                         OR 25 OR 29 OR 33
                      OR 800-C2 GREATER THAN 300-COMP-33.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           PERFORM VARYING 800-C1 FROM 300-COMP-4 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF 200-SOURCE-CODE (800-C1 : 15) EQUAL ' NEXT SENTENCE '
                   MOVE ' CONTINUE      '
                                       TO 200-SOURCE-CODE (800-C1 : 15)
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 15) EQUAL ' NEXT SENTENCE.'
                   MOVE ' CONTINUE.     '
                                       TO 200-SOURCE-CODE (800-C1 : 15)
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 9) EQUAL ' EXAMINE '
                   MOVE ' INSPECT '    TO 200-SOURCE-CODE (800-C1 : 9)
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 15) EQUAL ' WHEN-COMPILED '
                   MOVE ' CBL2-COMPILED '
                                       TO 200-SOURCE-CODE (800-C1 : 15)
                   SET 88-100-CBL2-COMPILED TO TRUE
                   ADD 300-COMP-1      TO 400-HIGH-USED-PL
                   SET PL              TO 400-HIGH-USED-PL
                   MOVE '.CBL2-WHEN-COMP-LINE '
                                       TO 580-COBOL-DATA (PL)
                   ADD 300-ONE         TO 400-TABLE-LINE-COUNT
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 14) EQUAL ' CURRENT-DATE '
                   MOVE ' CBL2-CURDATE '
                                       TO 200-SOURCE-CODE (800-C1 : 14)
                   SET 88-100-CBL2-CURDATE TO TRUE
                   ADD 300-COMP-1      TO 400-HIGH-USED-PL
                   SET PL              TO 400-HIGH-USED-PL
                   MOVE '.CBL2-CURDATE-LINE '
                                       TO 580-COBOL-DATA (PL)
                   ADD 300-ONE         TO 400-TABLE-LINE-COUNT
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 13) EQUAL ' TIME-OF-DAY '
                   MOVE ' CBL2-CURTOD '
                                       TO 200-SOURCE-CODE (800-C1 : 13)
                   SET 88-100-CBL2-CURTOD TO TRUE
                   ADD 300-COMP-1      TO 400-HIGH-USED-PL
                   SET PL              TO 400-HIGH-USED-PL
                   MOVE '.CBL2-CURTOD-LINE '
                                       TO 580-COBOL-DATA (PL)
                   ADD 300-ONE         TO 400-TABLE-LINE-COUNT
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 15) EQUAL ' EXHIBIT NAMED '
                   MOVE ' DISPLAY       '
                                       TO 200-SOURCE-CODE (800-C1 : 15)
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 9) EQUAL ' EXHIBIT '
                   MOVE ' DISPLAY '    TO 200-SOURCE-CODE (800-C1 : 9)
               END-IF
           END-PERFORM.
       EJECT
      ****************************************************************
      *    SHIFT MOVE STATEMENT TARGETS RIGHT TO COLUMN 40.          *
      ****************************************************************

       2111-20-ALIGN-MOVE-TARGETS.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           SET 88-100-NO-QUOTE-FOUND TO TRUE.
           PERFORM VARYING 800-C1 FROM 300-COMP-4 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF  200-SOURCE-CODE (800-C1 : 1) EQUAL QUOTE
                   IF 88-100-QUOTE-WAS-FOUND
                       SET 88-100-NO-QUOTE-FOUND TO TRUE
                   ELSE
                       SET 88-100-QUOTE-WAS-FOUND TO TRUE
                   END-IF
               END-IF
               IF  200-SOURCE-CODE (800-C1 : 4) EQUAL ' GO '
               AND 88-100-NO-QUOTE-FOUND
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
               IF  200-SOURCE-CODE (800-C1 : 4) EQUAL ' TO '
               AND 88-100-NO-QUOTE-FOUND
                   MOVE 800-C1         TO 800-C2
                   ADD 300-COMP-1      TO 800-C2
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
           END-PERFORM.

           IF  800-C2 GREATER THAN ZERO
           AND 800-C2 IS LESS THAN 300-COMP-33
               PERFORM 8400-SHIFT-STRING-RIGHT
                   UNTIL 800-C2 IS EQUAL TO  300-COMP-33
                      OR 800-C2 GREATER THAN 300-COMP-33.
       EJECT
      ****************************************************************
      *    2 1 1 1 - 3 0 - E D I T - C I C S - C A L L .             *
      ****************************************************************

       2111-30-EDIT-CICS-CALL.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           SET 88-100-NO-QUOTE-FOUND TO TRUE.
           PERFORM VARYING 800-C1 FROM 300-COMP-4 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF  200-SOURCE-CODE (800-C1 : 1) EQUAL QUOTE
                   IF 88-100-QUOTE-WAS-FOUND
                       SET 88-100-NO-QUOTE-FOUND TO TRUE
                   ELSE
                       SET 88-100-QUOTE-WAS-FOUND TO TRUE
                   END-IF
               END-IF
               IF 88-100-NO-QUOTE-FOUND
                   IF  200-SOURCE-CODE (800-C1 : 3) EQUAL 300-ENQ
                       SET 88-100-NOHANDLE-IS-BAD TO TRUE
                   END-IF
                   IF  200-SOURCE-CODE (800-C1 : 8) EQUAL 300-NOHANDLE
                       SET 88-100-NOHANDLE-IS-BAD TO TRUE
                   END-IF
                   IF  200-SOURCE-CODE (800-C1 : 4) EQUAL 300-RESP
                       SET 88-100-NOHANDLE-IS-BAD TO TRUE
                   END-IF
                   IF  200-SOURCE-CODE (800-C1 : 6) EQUAL 300-HANDLE
                   OR  200-SOURCE-CODE (800-C1 : 6) EQUAL 300-IGNORE
                       SET 88-100-NOHANDLE-IS-BAD TO TRUE
                   END-IF
                   IF  200-SOURCE-CODE (800-C1 : 9) EQUAL 300-END-EXECP
                       MOVE SPACES     TO 200-SOURCE-CODE (800-C1 : 9)
                       SET 88-100-END-EXECP-FOUND TO TRUE
                   ELSE
                       IF  200-SOURCE-CODE (800-C1 : 8)
                                                    EQUAL 300-END-EXEC
                           MOVE SPACES TO 200-SOURCE-CODE (800-C1 : 8)
                           SET 88-100-END-EXEC-FOUND TO TRUE
                       END-IF
                   END-IF
               END-IF
           END-PERFORM.
       EJECT
      ****************************************************************
      *    BEAUTIFY A DATA DIVISION 'PIC' LINE.                      *
      ****************************************************************

       2112-COMPRESS-PIC-LINE.

           PERFORM 2112-10-SHIFT-DATA-LEFT.

           PERFORM 2112-20-ALIGN-FD-STATEMENTS.

           PERFORM 2112-30-FIX-UP-PIC-CLAUSE.

           PERFORM 2112-40-ALIGN-REDEFINITION.

           PERFORM 2112-50-ALIGN-PIC-CLAUSE.

           PERFORM 2112-60-ALIGN-USAGE-CLAUSE.
       EJECT
      ****************************************************************
      *    COMPRESS A DATA DIVISION LINE.                            *
      ****************************************************************

       2112-10-SHIFT-DATA-LEFT.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           PERFORM 2112-11-CONVERT-PICTURES
               VARYING 800-C1 FROM 300-COMP-4 BY 1
               UNTIL   800-C1 IS GREATER THAN 300-COMP-65.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           PERFORM VARYING 800-C1 FROM 300-COMP-6 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF 200-SOURCE-CODE (800-C1 : 1) EQUAL QUOTE
                   MOVE 800-C1         TO 800-C2
                   ADD 300-COMP-1      TO 800-C2
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
           END-PERFORM.

           IF 800-C2 IS GREATER THAN 300-COMP-9
               PERFORM UNTIL 200-SOURCE-CODE (800-C2 - 2 : 1)
                             IS GREATER THAN SPACE
                          OR 800-C2 IS LESS THAN 300-COMP-9
                   SUBTRACT 300-COMP-1   FROM 800-C2
               END-PERFORM
               COMPUTE 800-C3 EQUAL 300-COMP-65 - 800-C2 + 300-COMP-1
               MOVE 200-SOURCE-CODE (800-C2 : 800-C3)
                                       TO 810-COMPRESS-WORK-1
               MOVE SPACES             TO 810-COMPRESS-WORK-2
               PERFORM 8300-COMPRESS-DATA-LINE
               MOVE 810-COMPRESS-WORK-2
                   TO 200-SOURCE-CODE (800-C2 : 800-C3).
       EJECT
      ****************************************************************
      *    CONVERT PICTURE CLAUSES FOR CLARITY.                      *
      ****************************************************************

       2112-11-CONVERT-PICTURES.

           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X     '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(1)  '
               MOVE ' PIC X(01) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X.    '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(1). '
               MOVE ' PIC X(01).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC XX    '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(2)  '
               MOVE ' PIC X(02) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC XX.   '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(2). '
               MOVE ' PIC X(02).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC XXX   '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(3)  '
               MOVE ' PIC X(03) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC XXX.  '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(3). '
               MOVE ' PIC X(03).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC XXXX  '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(4)  '
               MOVE ' PIC X(04) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC XXXX. '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(4). '
               MOVE ' PIC X(04).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(5)  '
               MOVE ' PIC X(05) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(5). '
               MOVE ' PIC X(05).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(6)  '
               MOVE ' PIC X(06) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(6). '
               MOVE ' PIC X(06).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(7)  '
               MOVE ' PIC X(07) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(7). '
               MOVE ' PIC X(07).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(8)  '
               MOVE ' PIC X(08) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(8). '
               MOVE ' PIC X(08).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(9)  '
               MOVE ' PIC X(09) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC X(9). '
               MOVE ' PIC X(09).'      TO 200-SOURCE-CODE (800-C1 : 11).

           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 9     '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 9(1)  '
               MOVE ' PIC 9(01) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 9.    '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 9(1). '
               MOVE ' PIC 9(01).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 99    '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 9(2)  '
               MOVE ' PIC 9(02) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 99.   '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 9(2). '
               MOVE ' PIC 9(02).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 999   '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 9(3)  '
               MOVE ' PIC 9(03) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 999.  '
           OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC 9(3). '
               MOVE ' PIC 9(03).'      TO 200-SOURCE-CODE (800-C1 : 11).

           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC S9    '
               MOVE ' PIC S9(1) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC S9.   '
               MOVE ' PIC S9(1).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC S99   '
               MOVE ' PIC S9(2) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC S99.  '
               MOVE ' PIC S9(2).'      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC S999  '
               MOVE ' PIC S9(3) '      TO 200-SOURCE-CODE (800-C1 : 11).
           IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' PIC S999. '
               MOVE ' PIC S9(3).'      TO 200-SOURCE-CODE (800-C1 : 11).
       EJECT
      ****************************************************************
      *    ALIGN ALL STATEMENTS IN A FILE SECTION 'FD' OR 'SD'.      *
      ****************************************************************

       2112-20-ALIGN-FD-STATEMENTS.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           PERFORM VARYING 800-C1 FROM 300-COMP-1 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF 200-SOURCE-CODE (800-C1 : 3) EQUAL 'FD '
               OR 200-SOURCE-CODE (800-C1 : 3) EQUAL 'SD '
                   MOVE 300-COMP-5     TO 800-C2
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 6) EQUAL ' DATA '
               OR 200-SOURCE-CODE (800-C1 : 7) EQUAL ' LABEL '
               OR 200-SOURCE-CODE (800-C1 : 7) EQUAL ' BLOCK '
               OR 200-SOURCE-CODE (800-C1 : 7) EQUAL ' RECORD'
                   MOVE 300-COMP-5     TO 800-C2
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 1) EQUAL QUOTE
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
           END-PERFORM.

           IF 800-C2 IS GREATER THAN ZERO
               COMPUTE 800-C3 EQUAL 300-COMP-65 - 800-C2 + 300-COMP-1
               MOVE 200-SOURCE-CODE (800-C2 : 800-C3)
                                       TO 810-COMPRESS-WORK-1
               MOVE SPACES             TO 810-COMPRESS-WORK-2
               PERFORM 8300-COMPRESS-DATA-LINE
               MOVE 810-COMPRESS-WORK-2
                   TO 200-SOURCE-CODE (800-C2 : 800-C3).
       EJECT
      ****************************************************************
      *    CHANGE 'PICTURE' TO 'PIC', IF REQUIRED.                   *
      ****************************************************************

       2112-30-FIX-UP-PIC-CLAUSE.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           PERFORM VARYING 800-C1 FROM 300-COMP-4 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF 200-SOURCE-CODE (800-C1 : 9) EQUAL ' PICTURE '
                   MOVE ' PIC     '    TO 200-SOURCE-CODE (800-C1 : 9)
                   MOVE 800-C1         TO 800-C2
                   ADD 300-COMP-1      TO 800-C2
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 5) EQUAL ' PIC '
               OR 200-SOURCE-CODE (800-C1 : 6) EQUAL ' COMP '
               OR 200-SOURCE-CODE (800-C1 : 6) EQUAL ' COMP.'
               OR 200-SOURCE-CODE (800-C1 : 8) EQUAL ' COMP-3 '
               OR 200-SOURCE-CODE (800-C1 : 8) EQUAL ' COMP-3.'
               OR 200-SOURCE-CODE (800-C1 : 8) EQUAL ' OCCURS '
               OR 200-SOURCE-CODE (800-C1 : 9) EQUAL ' INDEXED '
               OR 200-SOURCE-CODE (800-C1 : 11) EQUAL ' REDEFINES '
                   MOVE 800-C1         TO 800-C2
                   ADD 300-COMP-1      TO 800-C2
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 1) EQUAL QUOTE
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
           END-PERFORM.

           IF 800-C2 IS GREATER THAN ZERO
               PERFORM UNTIL 200-SOURCE-CODE (800-C2 - 2 : 1)
                             IS GREATER THAN SPACE
                          OR 800-C2 IS LESS THAN 300-COMP-20
                   SUBTRACT 300-COMP-1   FROM 800-C2
               END-PERFORM
               COMPUTE 800-C3 EQUAL 300-COMP-65 - 800-C2 + 300-COMP-1
               MOVE 200-SOURCE-CODE (800-C2 : 800-C3)
                                       TO 810-COMPRESS-WORK-1
               MOVE SPACES             TO 810-COMPRESS-WORK-2
               PERFORM 8300-COMPRESS-DATA-LINE
               MOVE 810-COMPRESS-WORK-2
                   TO 200-SOURCE-CODE (800-C2 : 800-C3).
       EJECT
      ****************************************************************
      *    ALIGN 'REDEFINES' TO COLUMN 40.                           *
      ****************************************************************

       2112-40-ALIGN-REDEFINITION.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           PERFORM VARYING 800-C1 FROM 300-COMP-4 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF 200-SOURCE-CODE (800-C1 : 11) EQUAL ' REDEFINES '
                   MOVE 800-C1         TO 800-C2
                   ADD 300-COMP-1      TO 800-C2
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 1) EQUAL QUOTE
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
           END-PERFORM.

           IF  800-C2 GREATER THAN ZERO
           AND 800-C2 IS LESS THAN 300-COMP-33
               PERFORM 8400-SHIFT-STRING-RIGHT
                   UNTIL 800-C2 IS EQUAL TO  300-COMP-33
                      OR 800-C2 GREATER THAN 300-COMP-33.
       EJECT
      ****************************************************************
      *    ALIGN 'PIC', ET CETERA, TO COLUMN 44.                     *
      ****************************************************************

       2112-50-ALIGN-PIC-CLAUSE.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           PERFORM VARYING 800-C1 FROM 300-COMP-4 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF 200-SOURCE-CODE (800-C1 : 5) EQUAL ' PIC '
               OR 200-SOURCE-CODE (800-C1 : 8) EQUAL ' OCCURS '
               OR 200-SOURCE-CODE (800-C1 : 9) EQUAL ' INDEXED '
                   MOVE 800-C1         TO 800-C2
                   ADD 300-COMP-1      TO 800-C2
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 1) EQUAL QUOTE
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
           END-PERFORM.

           IF  800-C2 GREATER THAN ZERO
           AND 800-C2 IS LESS THAN 300-COMP-37
               PERFORM 8400-SHIFT-STRING-RIGHT
                   UNTIL 800-C2 IS EQUAL TO  300-COMP-37
                      OR 800-C2 GREATER THAN 300-COMP-37.
       EJECT
      ****************************************************************
      *    ALIGN USAGE CLAUSES TO COLUMN 52.                         *
      ****************************************************************

       2112-60-ALIGN-USAGE-CLAUSE.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           PERFORM VARYING 800-C1 FROM 300-COMP-4 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF 200-SOURCE-CODE (800-C1 : 6) EQUAL ' COMP '
               OR 200-SOURCE-CODE (800-C1 : 6) EQUAL ' COMP.'
               OR 200-SOURCE-CODE (800-C1 : 7) EQUAL ' VALUE '
               OR 200-SOURCE-CODE (800-C1 : 8) EQUAL ' COMP-3 '
               OR 200-SOURCE-CODE (800-C1 : 8) EQUAL ' COMP-3.'
                   MOVE 800-C1         TO 800-C2
                   ADD 300-COMP-1      TO 800-C2
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
               IF 200-SOURCE-CODE (800-C1 : 1) EQUAL QUOTE
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
           END-PERFORM.

           IF  800-C2 GREATER THAN ZERO
           AND 800-C2 IS LESS THAN 300-COMP-49
               PERFORM 8400-SHIFT-STRING-RIGHT
                   UNTIL 800-C2 IS EQUAL TO  300-COMP-49
                      OR 800-C2 GREATER THAN 300-COMP-49.
       EJECT
      ****************************************************************
      *    2 1 1 3 - E X P A N D - A - L I N E .                     *
      ****************************************************************

       2113-EXPAND-A-LINE.

           MOVE 200-COBOL-RECORD       TO 800-HOLD-80-BYTES.
           MOVE ZERO                   TO 800-C2
           PERFORM VARYING 800-C1 FROM 300-COMP-4 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF 200-SOURCE-CODE (800-C1 : 1) EQUAL SPACE
                   MOVE 800-C1         TO 800-C2
                   ADD 300-COMP-1      TO 800-C2
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
           END-PERFORM.

           MOVE 800-C2                 TO 800-C3
           MOVE ZERO                   TO 800-C2
           PERFORM VARYING 800-C1 FROM 800-C3 BY 1
                   UNTIL 800-C1 IS GREATER THAN 300-COMP-65
               IF 200-SOURCE-CODE (800-C1 : 1) EQUAL SPACE
                   CONTINUE
               ELSE
                   MOVE 800-C1         TO 800-C2
                   MOVE 300-COMP-65    TO 800-C1
               END-IF
           END-PERFORM.

           IF  800-C2     IS GREATER THAN ZERO
           AND 800-C2     IS LESS    THAN 300-COMP-25
           AND 200-AREA-A IS GREATER THAN SPACES
               PERFORM 8400-SHIFT-STRING-RIGHT
                   UNTIL 800-C2 IS EQUAL TO  300-COMP-25
                      OR 800-C2 GREATER THAN 300-COMP-25
               MOVE ZERO               TO 800-C2.

           IF  800-C2     IS GREATER THAN 300-COMP-25
           AND 200-AREA-A IS GREATER THAN SPACES
               COMPUTE 800-C3 EQUAL
                   300-COMP-65 - 300-COMP-25 + 300-COMP-1
               MOVE 200-SOURCE-CODE (300-COMP-25 : 800-C3)
                                       TO 810-COMPRESS-WORK-1
               MOVE SPACES             TO 810-COMPRESS-WORK-2
               PERFORM 8300-COMPRESS-DATA-LINE
               MOVE 810-COMPRESS-WORK-2
                   TO 200-SOURCE-CODE (300-COMP-25 : 800-C3).

       EJECT
      ****************************************************************
      *    INITIALIZE THE VARIABLES USED FOR LEXICAL ANALYSIS.       *
      ****************************************************************

       2120-INITIALIZE-SCAN-PARMS.

           MOVE 300-COMP-1             TO 800-SUB.
           IF 88-200-CONTINUATION-LINE
               NEXT SENTENCE
           ELSE
               MOVE 300-COMP-1         TO 800-SUB2
               MOVE ZERO               TO 210-TOKEN-LENGTH
               MOVE SPACES             TO 210-TOKEN-VALUE.
       EJECT
      ****************************************************************
      *    EXTRACT THE TOKEN FROM THE INPUT STREAM BY COPYING 1 BYTE.*
      ****************************************************************

       2130-BUILD-ONE-TOKEN.

           PERFORM 8000-MOVE-ONE-TOKEN-BYTE.
       SKIP1
      ****************************************************************
      *    CASE 1 -- HANDLES QUOTED LITERALS                         *
      ****************************************************************
           IF 210-TOKEN-BYTE (800-SUB2 - 1) EQUAL QUOTE
               PERFORM 8000-MOVE-ONE-TOKEN-BYTE
               PERFORM UNTIL 800-SUB GREATER THAN 300-LINE-SCAN-LENGTH
               OR 210-TOKEN-BYTE (800-SUB2 - 1) EQUAL QUOTE
                   PERFORM 8000-MOVE-ONE-TOKEN-BYTE
               END-PERFORM
               SET 88-210-TOKEN-IS-ALPHA-LIT TO TRUE
               SET 88-100-END-OF-TOKEN TO TRUE
           ELSE
       SKIP1
      ****************************************************************
      *    CASE 2 -- HANDLES NUMERIC LITERALS WITH INITIAL SIGNS.    *
      ****************************************************************
           IF  200-SOURCE-CHAR (800-SUB) IS NUMERIC
           AND 800-SUB2 IS EQUAL TO 300-COMP-2
           AND (210-TOKEN-BYTE (800-SUB2 - 1) EQUAL 300-CHAR-PLUS
                                                 OR 300-CHAR-HYPHEN)
               SET 88-210-TOKEN-IS-NUMERIC-LIT TO TRUE
           ELSE
       SKIP1
      ****************************************************************
      *    CASE 3 -- HANDLES PERIOD EMBEDDED IN NUMERIC LITERAL.     *
      ****************************************************************
           IF  200-SOURCE-CHAR (800-SUB)     EQUAL 300-CHAR-PERIOD
           AND 210-TOKEN-BYTE (800-SUB2 - 1) IS NUMERIC
           AND 200-SOURCE-CHAR (800-SUB + 1) IS NUMERIC
               SET 88-210-TOKEN-IS-NUMERIC-LIT TO TRUE
               PERFORM 8000-MOVE-ONE-TOKEN-BYTE
               PERFORM UNTIL 800-SUB GREATER THAN 300-LINE-SCAN-LENGTH
               OR 200-SOURCE-CHAR (800-SUB) IS NOT NUMERIC
                   PERFORM 8000-MOVE-ONE-TOKEN-BYTE
               END-PERFORM
               SET 88-100-END-OF-TOKEN TO TRUE
           ELSE
       EJECT
      ****************************************************************
      *    CASE 4 -- HANDLES REPLICATED SPECIAL CHARACTERS           *
      ****************************************************************
           IF (210-TOKEN-BYTE (800-SUB2 - 1)
               IS EQUAL TO 300-CHAR-ASTERISK
                        OR 300-CHAR-PLUS
                        OR 300-CHAR-HYPHEN
                        OR 300-CHAR-EQUAL
                        OR 300-CHAR-LESS-THAN
                        OR 300-CHAR-GREATER-THAN)
           AND 200-SOURCE-CHAR (800-SUB) IS EQUAL TO
               210-TOKEN-BYTE  (800-SUB2 - 1)
               PERFORM 8000-MOVE-ONE-TOKEN-BYTE
               PERFORM UNTIL 800-SUB GREATER THAN 300-LINE-SCAN-LENGTH
               OR 200-SOURCE-CHAR (800-SUB) IS NOT EQUAL TO
                  210-TOKEN-BYTE  (800-SUB2 - 1)
                   PERFORM 8000-MOVE-ONE-TOKEN-BYTE
               END-PERFORM
               SET 88-100-END-OF-TOKEN TO TRUE
               SET 88-210-TOKEN-IS-SPECIAL TO TRUE
           ELSE
       SKIP1
      ****************************************************************
      *    CASE 5 -- HANDLES SINGLE-CHARACTER TERMINATING TOKENS.    *
      ****************************************************************
           IF  210-TOKEN-BYTE (800-SUB2 - 1)
               IS EQUAL TO 300-LEFT-PARENS
                        OR 300-RIGHT-PARENS
                        OR 300-CHAR-PLUS
                        OR 300-CHAR-COLON
                        OR 300-CHAR-PERIOD
                        OR 300-CHAR-COMMA
                        OR 300-CHAR-ASTERISK
                        OR 300-CHAR-SLASH
                        OR 300-CHAR-EQUAL
                        OR 300-CHAR-LESS-THAN
                        OR 300-CHAR-GREATER-THAN
               SET 88-100-END-OF-TOKEN TO TRUE
               SET 88-210-TOKEN-IS-SPECIAL TO TRUE
           ELSE
       EJECT
      ****************************************************************
      *    CASE 6 -- HANDLES ARITHMETIC OPERATORS.                   *
      ****************************************************************
           IF  200-SOURCE-CHAR (800-SUB) EQUAL SPACE
           AND (210-TOKEN-BYTE (800-SUB2 - 1)
                IS EQUAL TO 300-CHAR-HYPHEN
                         OR 300-CHAR-PLUS
                         OR 300-CHAR-ASTERISK
                         OR 300-CHAR-SLASH
                         OR 300-CHAR-EQUAL
                         OR 300-CHAR-LESS-THAN
                         OR 300-CHAR-GREATER-THAN)
               SET 88-100-END-OF-TOKEN TO TRUE
               SET 88-210-TOKEN-IS-SPECIAL TO TRUE
           ELSE
       SKIP1
      ****************************************************************
      *    CASE 7 -- TERMINATE TOKEN USING LOOKAHEAD CHARACTER.      *
      ****************************************************************
           IF 200-SOURCE-CHAR (800-SUB) EQUAL SPACE
                                           OR 300-LEFT-PARENS
                                           OR 300-RIGHT-PARENS
                                           OR 300-CHAR-COLON
                                           OR 300-CHAR-PERIOD
                                           OR 300-CHAR-COMMA
                                           OR 300-CHAR-PLUS
                                           OR 300-CHAR-ASTERISK
                                           OR 300-CHAR-SLASH
                                           OR 300-CHAR-EQUAL
                                           OR 300-CHAR-LESS-THAN
                                           OR 300-CHAR-GREATER-THAN
               SET 88-100-END-OF-TOKEN TO TRUE.
       EJECT
      ****************************************************************
      *    MODIFY THE TOKEN TYPE SO WE CAN DISTINGUISH LATER BETWEEN *
      *    KEYWORDS AND IDENTIFIERS (DATA-NAMES & PARAGRAPH-NAMES).  *
      ****************************************************************

       2140-IDENTIFY-TOKEN-TYPE.

           PERFORM 2141-EDIT-FOR-NUMERIC-LITERAL.

           IF 88-210-TOKEN-IS-UNKNOWN
               PERFORM 2142-EDIT-FOR-STD-IDENTIFIER.

           IF 88-210-TOKEN-IS-UNKNOWN
               PERFORM 2143-EDIT-FOR-COBOL-KEYWORDS.

           IF 88-210-TOKEN-IS-UNKNOWN
           OR 210-TOKEN-VALUE IS EQUAL TO 300-FILLER
               SET 88-210-TOKEN-IS-IDENTIFIER TO TRUE.
       EJECT
      ****************************************************************
      *    DETERMINE IN THE CURRENT TOKEN IS A NUMERIC LITERAL.      *
      ****************************************************************

       2141-EDIT-FOR-NUMERIC-LITERAL.

           IF  400-TOKEN-NUMBERS IS GREATER THAN ZERO
           AND 400-TOKEN-LETTERS IS EQUAL TO     ZERO
           AND 400-TOKEN-HYPHENS IS LESS THAN    300-TWO
               SET 88-210-TOKEN-IS-NUMERIC-LIT TO TRUE.
       SKIP3
      ****************************************************************
      *    DETERMINE IN THE CURRENT TOKEN IS A STANDARD IDENTIFIER.  *
      ****************************************************************

       2142-EDIT-FOR-STD-IDENTIFIER.

           IF  400-TOKEN-LETTERS IS GREATER THAN ZERO
           AND 400-TOKEN-NUMBERS IS GREATER THAN 300-TWO
           AND 400-TOKEN-HYPHENS IS GREATER THAN ZERO
               SET 88-210-TOKEN-IS-IDENTIFIER TO TRUE.
       SKIP3
      ****************************************************************
      *    DETERMINE IN THE CURRENT TOKEN IS A COBOL RESERVED WORD.  *
      ****************************************************************

       2143-EDIT-FOR-COBOL-KEYWORDS.

           MOVE 210-TOKEN-VALUE        TO 800-WORK-TOKEN-16
           SEARCH ALL 560-RESERVED-WORD
               AT END
                   SET 88-210-TOKEN-IS-IDENTIFIER TO TRUE
               WHEN 560-RESERVED-WORD (CW) EQUAL 800-WORK-TOKEN-16
                   SET 88-210-TOKEN-IS-KEYWORD TO TRUE
           END-SEARCH.
       EJECT
      ****************************************************************
      *    ANALYZE ONE COBOL TOKEN.                                  *
      ****************************************************************

       2200-ANALYZE-1-TOKEN.

           ADD 300-ONE TO 400-TOKEN-COUNT.

           IF 88-210-TOKEN-IS-EOL
      ***  OR 88-200-COMMENT-LINE
               CONTINUE
           ELSE
               IF NOT 88-200-COMMENT-LINE
                   PERFORM 2210-HANDLE-DIRECTIVES
               END-IF
               IF 88-210-ENVIRONMENT-DIVISION
                   PERFORM 2220-ANALYZE-ENV-DIVISION
               END-IF
               IF 88-210-DATA-DIVISION
                   PERFORM 2230-ANALYZE-DATA-DIVISION
               END-IF
               IF 88-210-PROCEDURE-DIVISION
                   PERFORM 2240-ANALYZE-PROC-DIVISION
               END-IF
               IF 88-210-IDENTIFICATION-DIVISION
                   PERFORM 2250-ANALYZE-ID-DIVISION
               END-IF
           END-IF.
       EJECT
      ****************************************************************
      *    HANDLE COMPILER DIRECTING COMMANDS.                       *
      ****************************************************************

       2210-HANDLE-DIRECTIVES.

           IF  230-3RD-TOKEN-VALUE EQUAL 300-PROGRAM-ID
           AND 220-LAST-TOKEN-VALUE EQUAL 300-CHAR-PERIOD
           AND 200-INDICATOR-AREA   EQUAL SPACE
               SET 800-CBL2-ID-LINE    TO PL
               ADD 1 TO 800-CBL2-ID-LINE
               MOVE 210-TOKEN-VALUE    TO 800-PROGRAM-ID
               MOVE 800-PROGRAM-ID     TO 600-DISPLAY-PGM.

           IF 210-TOKEN-VALUE EQUAL 300-EJECT
               SET 88-100-EJECT-FOUND  TO TRUE.
           IF 210-TOKEN-VALUE EQUAL 300-SKIP1
               SET 88-100-SKIP1-FOUND  TO TRUE.
           IF 210-TOKEN-VALUE EQUAL 300-SKIP2
               SET 88-100-SKIP2-FOUND  TO TRUE.
           IF 210-TOKEN-VALUE EQUAL 300-SKIP3
               SET 88-100-SKIP3-FOUND  TO TRUE.

           IF  200-INDICATOR-AREA EQUAL SPACE
           AND 210-TOKEN-VALUE EQUAL 300-DIVISION
               PERFORM 2211-PROCESS-DIVISION-HEADER.

           IF  210-TOKEN-VALUE EQUAL 300-SECTION
               PERFORM 2212-PROCESS-SECTION-HEADER.
       EJECT
      ****************************************************************
      *    2 2 1 1 - P R O C E S S - D I V I S I O N - H E A D E R . *
      ****************************************************************

       2211-PROCESS-DIVISION-HEADER.

           EVALUATE 220-LAST-TOKEN-VALUE
               WHEN 300-IDENTIFICATION
               WHEN 300-ID
                   SET 800-ID-DIV-LINE TO PL
                   IF PL IS GREATER THAN 300-COMP-1
                       MOVE 300-CHAR-B TO 580-VERTICAL-ACTION (PL)
                       ADD 300-ONE     TO 800-ID-DIV-LINE
                   END-IF
                   SET 88-210-IDENTIFICATION-DIVISION TO TRUE
               WHEN 300-ENVIRONMENT
                   SET 800-ENV-DIV-LINE TO PL
                   ADD 300-ONE         TO 800-ENV-DIV-LINE
                   MOVE 300-CHAR-E TO 580-VERTICAL-ACTION (PL)
                   SET 88-210-ENVIRONMENT-DIVISION TO TRUE
               WHEN 300-DATA
                   SET 800-DATA-DIV-LINE TO PL
                   ADD 300-ONE         TO 800-DATA-DIV-LINE
                   MOVE 300-CHAR-E     TO 580-VERTICAL-ACTION (PL)
                   SET 88-210-DATA-DIVISION TO TRUE
               WHEN 300-PROCEDURE
                   IF 800-CBL2-WS-LINE EQUAL ZERO
                       SET 800-CBL2-WS-LINE TO PL
                       ADD 300-ONE     TO 800-CBL2-WS-LINE
                   END-IF
                   SET 800-PROC-DIV-LINE TO PL
                   ADD 300-ONE         TO 800-PROC-DIV-LINE
                   MOVE 300-CHAR-E     TO 580-VERTICAL-ACTION (PL)
                   SET 88-210-PROCEDURE-DIVISION TO TRUE
           END-EVALUATE.
       EJECT
      ****************************************************************
      *    2 2 1 2 - P R O C E S S - S E C T I O N - H E A D E R .   *
      ****************************************************************

       2212-PROCESS-SECTION-HEADER.

           MOVE 300-CHAR-B             TO 580-VERTICAL-ACTION (PL).
           MOVE 300-CHAR-B             TO 580-VERTICAL-ACTION (PL + 1).
           EVALUATE 220-LAST-TOKEN-VALUE
               WHEN 300-CONFIGURATION
                   SET 800-CFG-SECT-LINE  TO PL
                   ADD 300-ONE         TO 800-CFG-SECT-LINE
               WHEN 300-INPUT-OUTPUT
                   SET 800-IO-SECT-LINE  TO PL
                   ADD 300-ONE         TO 800-IO-SECT-LINE
               WHEN 300-FILE
                   SET 800-FILE-SECT-LINE  TO PL
                   ADD 300-ONE         TO 800-FILE-SECT-LINE
               WHEN 300-WORKING-STORAGE
                   SET 800-WS-SECT-LINE    TO PL
                   ADD 300-ONE         TO 800-WS-SECT-LINE
                   IF 800-FILE-SECT-LINE EQUAL ZERO
                       MOVE 300-CHAR-B TO 580-VERTICAL-ACTION (PL)
                   ELSE
                       MOVE 300-CHAR-E TO 580-VERTICAL-ACTION (PL)
                   END-IF
               WHEN 300-LINKAGE
                   SET 800-CBL2-WS-LINE    TO PL
                   ADD 300-ONE         TO 800-CBL2-WS-LINE
                   SET 800-LINK-SECT-LINE  TO PL
                   ADD 300-ONE         TO 800-LINK-SECT-LINE
                   MOVE 300-CHAR-E     TO 580-VERTICAL-ACTION (PL)
                   IF  800-FILE-SECT-LINE EQUAL ZERO
                   AND 800-WS-SECT-LINE   EQUAL ZERO
                       MOVE 300-CHAR-B TO 580-VERTICAL-ACTION (PL)
                   ELSE
                       MOVE 300-CHAR-E TO 580-VERTICAL-ACTION (PL)
                   END-IF
               WHEN OTHER
                   MOVE 300-CHAR-E     TO 580-VERTICAL-ACTION (PL)
           END-EVALUATE.
       EJECT
      ****************************************************************
      *    ANALYZE ENVIRONMENT DIVISION TOKEN FOR ERRORS.            *
      ****************************************************************

       2220-ANALYZE-ENV-DIVISION.

           IF 88-200-COMMENT-LINE
               CONTINUE
           ELSE
               IF 210-TOKEN-VALUE EQUAL 300-SELECT
                   MOVE 300-CHAR-B     TO 580-VERTICAL-ACTION (PL)
               END-IF
           END-IF.
       SKIP3
      ****************************************************************
      *    ANALYZE DATA DIVISION TOKEN FOR ERRORS.                   *
      ****************************************************************

       2230-ANALYZE-DATA-DIVISION.

           IF 88-200-COMMENT-LINE
               CONTINUE
           ELSE
               IF  88-210-TOKEN-IS-IN-AREA-A
               AND 210-TOKEN-VALUE EQUAL 300-COBOL-77
                   MOVE 300-COBOL-01   TO 210-TOKEN-VALUE
                   MOVE 300-COBOL-01   TO 200-SOURCE-CODE
                       (210-TOKEN-START : 210-TOKEN-LENGTH)
               END-IF
               IF  88-210-TOKEN-IS-IN-AREA-A
               AND (210-TOKEN-VALUE EQUAL 300-COBOL-01
                                       OR 300-COBOL-FD
                                       OR 300-COBOL-SD)
                   MOVE 300-CHAR-B     TO 580-VERTICAL-ACTION (PL)
               END-IF
               IF  210-TOKEN-VALUE EQUAL 300-PICTURE
                   MOVE SPACES         TO 200-SOURCE-CODE
                       (210-TOKEN-START : 210-TOKEN-LENGTH)
                   MOVE 300-PIC        TO 200-SOURCE-CODE
                       (210-TOKEN-START : 3)
               END-IF
               PERFORM 2231-CAPTURE-BLL-CELL-ADDR
           END-IF.
       EJECT
      ****************************************************************
      *    2 2 3 1 - C A P T U R E - B L L - C E L L - A D D R .     *
      ****************************************************************

       2231-CAPTURE-BLL-CELL-ADDR.

           IF 88-100-PARMLIST-WAS-FOUND
               MOVE 300-CHAR-PERIOD    TO 200-INDICATOR-AREA
               IF 210-TOKEN-VALUE (1:3) EQUAL 300-PIC
                   IF 220-LAST-TOKEN-VALUE EQUAL 300-FILLER
                       CONTINUE
                   ELSE
                       PERFORM 2231-10-SAVE-1-BLL-ADDR
                   END-IF
               END-IF
               IF  210-TOKEN-VALUE EQUAL 300-COBOL-01
               AND 88-210-TOKEN-IS-IN-AREA-A
                   SET 88-100-NO-COMMAREA-FOUND TO TRUE
                   MOVE SPACE          TO 200-INDICATOR-AREA
               END-IF
               IF 210-TOKEN-VALUE (1:5) EQUAL 'COPY '
               OR 210-TOKEN-VALUE (1:6) EQUAL 'EJECT '
               OR 210-TOKEN-VALUE (1:8) EQUAL 'INCLUDE '
                   SET 88-100-NO-COMMAREA-FOUND TO TRUE
                   MOVE SPACE          TO 200-INDICATOR-AREA
               END-IF
           END-IF.

           IF 88-100-COMMAREA-WAS-FOUND
               IF  210-TOKEN-VALUE EQUAL 300-COBOL-01
               AND 88-210-TOKEN-IS-IN-AREA-A
                   SET 88-100-PARMLIST-WAS-FOUND TO TRUE
               END-IF
           END-IF.

           IF 88-100-NO-COMMAREA-FOUND
               IF 210-TOKEN-VALUE EQUAL 300-DFHCOMMAREA
                   SET 88-100-COMMAREA-WAS-FOUND TO TRUE
               END-IF
           END-IF.

           IF  220-LAST-TOKEN-VALUE (1:5) EQUAL 'COPY '
           AND 210-TOKEN-VALUE (1:8)      EQUAL 'DFHCSADS'
               MOVE 300-CHAR-PERIOD    TO 200-INDICATOR-AREA.
       EJECT
      ****************************************************************
      *    2 2 3 1 - 1 0 - S A V E - 1 - B L L - A D D R .           *
      ****************************************************************

       2231-10-SAVE-1-BLL-ADDR.

           SET PT                      TO 300-ONE.
           SEARCH 500-CICS-PTR-ENTRY VARYING PT
               AT END
                   CONTINUE
               WHEN 500-CICS-BLL-ADDR (PT) EQUAL SPACES
                   MOVE 220-LAST-TOKEN-VALUE
                                       TO 500-CICS-BLL-ADDR (PT)
      ****       DISPLAY '  '
      ****       DISPLAY 'BLL-CELL-ADDR = ' 220-LAST-TOKEN-VALUE
                   IF 220-LAST-TOKEN-LENGTH IS LESS THAN 29
                       MOVE '-PTR'     TO 220-LAST-TOKEN-VALUE
                                   (220-LAST-TOKEN-LENGTH + 1 : 4)
                   ELSE
                       SET 800-NEW-CICS-PTR-NBR TO PT
                       IF 220-LAST-TOKEN-VALUE (23:1) EQUAL '-'
                           MOVE 800-NEW-CICS-PTR (2:7)
                                       TO 220-LAST-TOKEN-VALUE (24:)
                       ELSE
                           MOVE 800-NEW-CICS-PTR
                                       TO 220-LAST-TOKEN-VALUE (23:)
                       END-IF
                   END-IF
                   MOVE 220-LAST-TOKEN-VALUE
                                       TO 500-CICS-BLL-PTR (PT)
                   ADD +1              TO 400-CICS-PTR-COUNT
      *****      MOVE 500-CICS-BLL-PTR (PT)
      *****                            TO 220-LAST-TOKEN-VALUE
      *****      DISPLAY 'BLL-CELL-PTR  = ' 220-LAST-TOKEN-VALUE
      *****      DISPLAY '400-CICS-PTR-COUNT = ' 400-CICS-PTR-COUNT
           END-SEARCH.
       EJECT
      ****************************************************************
      *    ANALYZE PROCEDURE DIVISION TOKEN FOR ERRORS.              *
      ****************************************************************

       2240-ANALYZE-PROC-DIVISION.

           IF 88-200-COMMENT-LINE
               NEXT SENTENCE
           ELSE
               IF  88-210-TOKEN-IS-IN-AREA-A
               AND 88-210-TOKEN-IS-IDENTIFIER
                   IF 88-100-THIS-IS-FIRST-PARAGRAPH
                       MOVE 300-CHAR-B TO 580-VERTICAL-ACTION (PL)
                       MOVE 300-CHAR-N TO 100-FIRST-PARA-FLAG
                   ELSE
                       MOVE 300-CHAR-E TO 580-VERTICAL-ACTION (PL)
                   END-IF
                   MOVE 300-CHAR-B     TO 580-VERTICAL-ACTION (PL + 1)
               END-IF
               IF  210-TOKEN-VALUE EQUAL 300-EXIT
                   MOVE 300-CHAR-X     TO 580-VERTICAL-ACTION (PL)
               END-IF
               PERFORM 2241-CHECK-FOR-TARGETS
               PERFORM 2242-ANALYZE-EXEC-CALLS
               IF  88-210-TOKEN-IS-IN-AREA-B
               AND 88-210-TOKEN-IS-IDENTIFIER
                   IF  230-3RD-TOKEN-VALUE EQUAL 'SERVICE'
                   AND 220-LAST-TOKEN-VALUE EQUAL 'RELOAD'
                       PERFORM 2244-BUILD-SET-ADDRESS
                   END-IF
               END-IF
               IF  88-210-TOKEN-IS-IN-AREA-B
               AND 88-210-TOKEN-IS-IDENTIFIER
                   PERFORM 2245-FIND-CURRENT-CICS-PTR
               END-IF
               IF 210-TOKEN-VALUE (1:10) EQUAL 'SI84801001'
                   IF  88-100-INSERT-NOHANDLE
                       MOVE 300-CHAR-PERIOD    TO 200-INDICATOR-AREA
                   END-IF
               END-IF
           END-IF.
           PERFORM 2243-CHECK-FOR-NOTE-VERB.
       EJECT
      ****************************************************************
      *    2 2 4 1 - C H E C K - F O R - T A R G E T S .             *
      ****************************************************************

       2241-CHECK-FOR-TARGETS.

      ****************************************************************
      *    FIRST RESET ALL FLAGS TO INITIAL VALUES, IF REQUIRED.     *
      ****************************************************************

           IF 88-820-FIX-TARGETS
           OR 88-820-MOVE-TO-IS-ACTIVE
           OR 88-820-USING-IS-ACTIVE
               IF 210-LINE-NUMBER EQUAL 220-LAST-LINE-NUMBER
                   CONTINUE
               ELSE
                   IF 88-210-TOKEN-IS-IN-AREA-A
                   OR 88-210-TOKEN-IS-KEYWORD
                   OR 220-LAST-TOKEN-VALUE EQUAL 300-CHAR-PERIOD
                   OR 210-TOKEN-VALUE      EQUAL 300-EXAMINE
                   OR 210-TOKEN-VALUE      EQUAL 300-NOTE
                       SET 88-820-BYPASS-TARGET-FIX     TO TRUE
                       SET 88-820-USING-IS-NOT-ACTIVE   TO TRUE
                       SET 88-820-MOVE-IS-NOT-ACTIVE    TO TRUE
                       SET 88-820-MOVE-TO-IS-NOT-ACTIVE TO TRUE
                       MOVE +24        TO 820-ALIGNMENT-COLUMN
                   END-IF
               END-IF
           END-IF.
       EJECT
      ****************************************************************
      *    THIS CODE CHECKS FOR MULTIPLE 'MOVE ... TO' TARGETS.      *
      ****************************************************************

           IF 210-TOKEN-VALUE EQUAL 300-MOVE
               SET 88-820-MOVE-IS-ACTIVE TO TRUE
           END-IF.

           IF 88-820-MOVE-IS-ACTIVE
               IF  220-LAST-TOKEN-VALUE EQUAL 300-TO
                   SET 88-820-MOVE-TO-IS-ACTIVE TO TRUE
                   IF 88-100-ALIGN-TARGET
                       MOVE +43        TO 820-ALIGNMENT-COLUMN
                   ELSE
                       COMPUTE 820-ALIGNMENT-COLUMN EQUAL
                           (210-TOKEN-START + 7)
                   END-IF
               END-IF
           END-IF.

           IF 88-820-MOVE-TO-IS-ACTIVE
               IF 210-LINE-NUMBER EQUAL 220-LAST-LINE-NUMBER
                   CONTINUE
               ELSE
                   IF  88-210-TOKEN-IS-IDENTIFIER
                   AND 88-210-TOKEN-IS-IN-AREA-B
                       SET 88-820-FIX-TARGETS TO TRUE
                   END-IF
               END-IF
           END-IF.
       SKIP1
      ****************************************************************
      *    THIS CODE CHECKS FOR MULTIPLE 'CALL ... USING' TARGETS.   *
      ****************************************************************

           IF  220-LAST-TOKEN-VALUE EQUAL 300-USING
           AND 220-LAST-LINE-NUMBER EQUAL 210-LINE-NUMBER
               SET 88-820-USING-IS-ACTIVE TO TRUE
               COMPUTE 820-ALIGNMENT-COLUMN EQUAL
                   (210-TOKEN-START + 7)
           END-IF.

           IF 88-820-USING-IS-ACTIVE
               IF 210-LINE-NUMBER EQUAL 220-LAST-LINE-NUMBER
                   CONTINUE
               ELSE
                   IF  88-210-TOKEN-IS-IDENTIFIER
                   AND 88-210-TOKEN-IS-IN-AREA-B
                       SET 88-820-FIX-TARGETS TO TRUE
                   END-IF
               END-IF
           END-IF.
       EJECT
      ****************************************************************
      *    2 2 4 2 - A N A L Y Z E - E X E C - C A L L S .           *
      ****************************************************************

       2242-ANALYZE-EXEC-CALLS.

           IF 220-LAST-TOKEN-VALUE EQUAL 300-EXEC
               MOVE 220-LAST-TOKEN-START  TO 400-CICS-EXEC-POS
               SET 88-100-CICS-EXEC-FOUND TO TRUE
               IF 210-TOKEN-VALUE EQUAL 300-CICS
                   IF 88-100-INSERT-NOHANDLE
                       SET 88-100-VALID-NOHANDLE TO TRUE
                   ELSE
                       SET 88-100-NOHANDLE-IS-BAD TO TRUE
                   END-IF
               END-IF
           END-IF.

           IF 88-100-CICS-EXEC-FOUND
               IF 210-TOKEN-VALUE EQUAL 300-ENQ
               OR 210-TOKEN-VALUE EQUAL 300-SQL
               OR 210-TOKEN-VALUE EQUAL 300-NOHANDLE
               OR 210-TOKEN-VALUE EQUAL 300-HANDLE
               OR 210-TOKEN-VALUE EQUAL 300-IGNORE
               OR 210-TOKEN-VALUE EQUAL 300-RESP
                   SET 88-100-NOHANDLE-IS-BAD TO TRUE
               END-IF
           END-IF.
       EJECT
      ****************************************************************
      *    2 2 4 3 - C H E C K - F O R - N O T E - V E R B .         *
      ****************************************************************

       2243-CHECK-FOR-NOTE-VERB.

           IF  88-100-NOTE-PARANAME-FOUND
               IF 88-210-TOKEN-IS-KEYWORD
                   SET 88-100-NOTE-SCOPE-IS-OFF TO TRUE
               END-IF
           END-IF.

           IF  88-100-NOTE-VERB-BUT-SECOND
               IF 210-TOKEN-VALUE EQUAL 300-CHAR-PERIOD
                   SET 88-100-NOTE-SCOPE-IS-OFF TO TRUE
               END-IF
           END-IF.

           IF 210-LINE-NUMBER IS GREATER THAN 220-LAST-LINE-NUMBER
               IF  88-210-TOKEN-IS-IDENTIFIER
               AND 88-210-TOKEN-IS-IN-AREA-A
                   SET 88-100-NOTE-PARANAME-FOUND TO TRUE
               ELSE
                   IF 88-100-NOTE-VERB-FIRST
                        SET 88-200-COMMENT-LINE   TO TRUE
                   END-IF
               END-IF
               IF 88-100-NOTE-VERB-BUT-SECOND
                    SET 88-200-COMMENT-LINE   TO TRUE
               END-IF
           END-IF.

           IF 88-200-COMMENT-LINE
               CONTINUE
           ELSE
               IF  210-TOKEN-VALUE EQUAL 300-NOTE
                   IF 88-100-NOTE-PARANAME-FOUND
                       SET 88-100-NOTE-VERB-FIRST TO TRUE
                       SET 88-200-COMMENT-LINE    TO TRUE
                   END-IF
                   IF 88-100-NOTE-SCOPE-IS-OFF
                       SET 88-100-NOTE-VERB-BUT-SECOND TO TRUE
                       SET 88-200-COMMENT-LINE         TO TRUE
                   END-IF
               END-IF
           END-IF.
       EJECT
      ****************************************************************
      *    2 2 4 4 - B U I L D - S E T - A D D R E S S .             *
      ****************************************************************

       2244-BUILD-SET-ADDRESS.

           MOVE 300-CHAR-PERIOD        TO 830-LITERAL-DOT.
           MOVE 210-TOKEN-VALUE        TO 830-DSECT-NAME.
           MOVE 800-CURRENT-CICS-PTR   TO 830-POINTER-NAME.
           MOVE ZERO                   TO 400-DOT-COUNT.
           INSPECT 200-COBOL-RECORD TALLYING 400-DOT-COUNT
               FOR ALL '.'.
           IF 400-DOT-COUNT IS GREATER THAN ZERO
               MOVE 300-CHAR-PERIOD    TO 830-PERIOD
           ELSE
               MOVE SPACE              TO 830-PERIOD.

           IF 100-FIRST-SERV-RELOAD EQUAL 'Y'
               MOVE 'N'                TO 100-FIRST-SERV-RELOAD
               MOVE 300-CHAR-PERIOD    TO 200-INDICATOR-AREA
           ELSE
      *****      DISPLAY 830-SET-ADDRESS-WORK-LINE
               MOVE 830-SET-ADDRESS-WORK-LINE
                                       TO 200-COBOL-RECORD.
       SKIP3
      ****************************************************************
      *    2 2 4 5 - F I N D - C U R R E N T - C I C S - P T R .     *
      ****************************************************************

       2245-FIND-CURRENT-CICS-PTR.

           SET PT                      TO 300-ONE.
           SEARCH 500-CICS-PTR-ENTRY VARYING PT
               AT END
                   CONTINUE
               WHEN 500-CICS-BLL-ADDR (PT) EQUAL 210-TOKEN-VALUE
                   MOVE 500-CICS-BLL-PTR (PT)
                                       TO 800-CURRENT-CICS-PTR
      *****          DISPLAY '800-CURRENT-CICS-PTR = '
      *****                   800-CURRENT-CICS-PTR
           END-SEARCH.
       EJECT
      ****************************************************************
      *    ANALYZE IDENTIFICATION DIVISION TOKEN FOR CHANGES.        *
      ****************************************************************

       2250-ANALYZE-ID-DIVISION.

           IF 88-200-COMMENT-LINE
               NEXT SENTENCE
           ELSE
               IF 210-TOKEN-VALUE EQUAL 'AUTHOR        '
                                     OR 'INSTALLATION  '
                                     OR 'DATE-WRITTEN  '
                                     OR 'DATE-COMPILED '
                                     OR 'SECURITY      '
                                     OR 'REMARKS       '
                   SET 88-200-COMMENT-LINE TO TRUE
               END-IF
           END-IF.
       EJECT
      ****************************************************************
      *    LOAD 1 COBOL PROGRAM LINE INTO THE TABLE.                 *
      ****************************************************************

       2300-LOAD-1-COBOL-LINE.

           IF 88-210-IDENTIFICATION-DIVISION
               IF  800-CBL2-ID-LINE IS GREATER THAN ZERO
               AND PL               IS GREATER THAN 800-CBL2-ID-LINE
                   SET 88-200-COMMENT-LINE TO TRUE
               END-IF
           END-IF.

           IF 88-200-COMMENT-LINE
           OR 200-COBOL-RECORD (7:66) EQUAL SPACES
               NEXT SENTENCE
           ELSE
               IF 88-820-FIX-TARGETS
                   PERFORM 2330-FIX-IDENTIFIER-TARGETS
               END-IF
           END-IF.

           EVALUATE TRUE
               WHEN 200-COBOL-RECORD (7:66) EQUAL SPACES
                   IF 88-100-END-EXECP-FOUND
                   OR 88-100-END-EXEC-FOUND
                       ADD 300-ONE     TO 400-OLD-LINES-DROPPED
                       PERFORM 8500-INSERT-A-NOHANDLE
                       MOVE SPACE      TO 580-VERTICAL-ACTION (PL + 1)
                   ELSE
                       ADD 300-ONE     TO 400-OLD-LINES-DROPPED
                       IF PL IS GREATER THAN ZERO
                       AND 580-VERTICAL-ACTION (PL) EQUAL SPACE
                           MOVE 300-CHAR-B
                                       TO 580-VERTICAL-ACTION (PL)
                       END-IF
                       MOVE SPACE      TO 580-VERTICAL-ACTION (PL + 1)
                   END-IF
               WHEN 88-100-SKIP1-FOUND
                   IF PL IS GREATER THAN ZERO
                   AND 580-VERTICAL-ACTION (PL) EQUAL 300-CHAR-H
                       ADD 300-ONE     TO 400-OLD-LINES-DROPPED
                   ELSE
                       ADD 300-ONE     TO 400-OLD-LINES-DROPPED
                       MOVE 300-CHAR-1 TO 580-VERTICAL-ACTION (PL)
                       MOVE SPACE      TO 580-VERTICAL-ACTION (PL + 1)
                   END-IF
               WHEN 88-100-SKIP2-FOUND
                   IF PL IS GREATER THAN ZERO
                   AND 580-VERTICAL-ACTION (PL) EQUAL 300-CHAR-H
                       ADD 300-ONE     TO 400-OLD-LINES-DROPPED
                   ELSE
                       ADD 300-ONE     TO 400-OLD-LINES-DROPPED
                       MOVE 300-CHAR-2 TO 580-VERTICAL-ACTION (PL)
                       MOVE SPACE      TO 580-VERTICAL-ACTION (PL + 1)
                   END-IF
               WHEN 88-100-SKIP3-FOUND
                   IF PL IS GREATER THAN ZERO
                   AND 580-VERTICAL-ACTION (PL) EQUAL 300-CHAR-H
                       ADD 300-ONE     TO 400-OLD-LINES-DROPPED
                   ELSE
                       ADD 300-ONE     TO 400-OLD-LINES-DROPPED
                       MOVE 300-CHAR-3 TO 580-VERTICAL-ACTION (PL)
                       MOVE SPACE      TO 580-VERTICAL-ACTION (PL + 1)
                   END-IF
               WHEN 88-100-EJECT-FOUND
                   IF PL IS GREATER THAN ZERO
                   AND 580-VERTICAL-ACTION (PL) EQUAL 300-CHAR-H
                       ADD 300-ONE     TO 400-OLD-LINES-DROPPED
                   ELSE
                       ADD 300-ONE     TO 400-OLD-LINES-DROPPED
                       MOVE 300-CHAR-E TO 580-VERTICAL-ACTION (PL)
                       MOVE SPACE      TO 580-VERTICAL-ACTION (PL + 1)
                   END-IF
               WHEN 88-200-COMMENT-LINE
                   PERFORM 2310-LOAD-1-COMMENT-LINE
               WHEN 200-INDICATOR-AREA EQUAL 300-CHAR-PERIOD
                   CONTINUE
               WHEN 200-COBOL-RECORD (8:1) EQUAL 300-CHAR-PERIOD
                   MOVE 830-DSECT-NAME TO 700-DSECT-NAME
                   ADD 300-COMP-1      TO 400-HIGH-USED-PL
                   SET PL              TO 400-HIGH-USED-PL
                   MOVE 700-SET-ADDR-LINE-1
                                       TO 580-COBOL-DATA (PL)
                   ADD 300-ONE         TO 400-TABLE-LINE-COUNT
                   MOVE 830-POINTER-NAME
                                       TO 700-POINTER-NAME
                   IF 830-PERIOD EQUAL 300-CHAR-PERIOD
                       INSPECT 700-POINTER-NAME
                           REPLACING FIRST SPACE BY '.'
                   END-IF
                   ADD 300-COMP-1      TO 400-HIGH-USED-PL
                   SET PL              TO 400-HIGH-USED-PL
                   MOVE 700-SET-ADDR-LINE-2
                                       TO 580-COBOL-DATA (PL)
                   ADD 300-ONE         TO 400-TABLE-LINE-COUNT
               WHEN 88-100-TITLE-FOUND
               WHEN 88-100-NORMAL-PRINT
                   PERFORM 2320-LOAD-1-SOURCE-LINE
                   PERFORM 8500-INSERT-A-NOHANDLE
               WHEN OTHER
                   CONTINUE
           END-EVALUATE.

           IF 400-HIGH-USED-PL IS LESS THAN 300-MAXIMUM-PL
               CONTINUE
           ELSE
               DISPLAY 600-TABLE-FULL-MSG
               ADD 300-ONE             TO 800-DUMP
           END-IF.
       EJECT
      ****************************************************************
      *    2 3 1 0 - L O A D - 1 - C O M M E N T - L I N E .         *
      ****************************************************************

       2310-LOAD-1-COMMENT-LINE.

           IF  200-SOURCE-CODE EQUAL SPACES
               IF 580-LINE-TYPE (PL) EQUAL 300-CHAR-ASTERISK
                                        OR 300-CHAR-C
                   ADD 300-ONE         TO 400-HIGH-USED-PL
                   SET PL              TO 400-HIGH-USED-PL
                   PERFORM 8100-ADJUST-COMMENT-LINE
                   MOVE 200-COBOL-RECORD (7:66)
                                       TO 580-COBOL-DATA (PL)
                   ADD 300-ONE         TO 400-TABLE-LINE-COUNT
               ELSE
                   IF PL IS GREATER THAN ZERO
                       ADD 300-ONE     TO 400-OLD-LINES-DROPPED
                       MOVE 300-CHAR-B TO 580-VERTICAL-ACTION (PL)
                   END-IF
               END-IF
           ELSE
               ADD 300-COMP-1          TO 400-HIGH-USED-PL
               SET PL                  TO 400-HIGH-USED-PL
               PERFORM 8100-ADJUST-COMMENT-LINE
               MOVE 200-COBOL-RECORD (7:66)
                                       TO 580-COBOL-DATA (PL)
               ADD 300-ONE             TO 400-TABLE-LINE-COUNT
           END-IF.
       EJECT
      ****************************************************************
      *    2 3 2 0 - L O A D - 1 - S O U R C E - L I N E .           *
      ****************************************************************

       2320-LOAD-1-SOURCE-LINE.

           ADD 300-COMP-1              TO 400-HIGH-USED-PL.
           SET PL                      TO 400-HIGH-USED-PL.
           MOVE 200-COBOL-RECORD (7:66)
                                       TO 580-COBOL-DATA (PL).
           ADD 300-ONE                 TO 400-TABLE-LINE-COUNT.


           IF  88-210-PROCEDURE-DIVISION
           AND 200-AREA-A IS GREATER THAN SPACES
               MOVE 300-CHAR-H         TO 580-VERTICAL-ACTION (PL)
           END-IF.
       EJECT
      ****************************************************************
      *    2 3 3 0 - F I X - I D E N T I F I E R - T A R G E T S .   *
      ****************************************************************

       2330-FIX-IDENTIFIER-TARGETS.

           MOVE 820-ALIGNMENT-COLUMN   TO 820-BASE.
           MOVE +8                     TO 820-COUNT.
           PERFORM VARYING 800-SUB FROM +8 BY +1
                   UNTIL 200-SOURCE-CHAR (800-SUB) GREATER THAN SPACE
                      OR 800-SUB IS GREATER THAN +71
           END-PERFORM.
           COMPUTE 820-COUNT EQUAL (800-SUB + 7).

           IF 820-BASE EQUAL 820-COUNT
               CONTINUE
           ELSE
               IF 820-BASE IS GREATER THAN 820-COUNT
                   COMPUTE 820-SHIFT EQUAL (820-BASE - 820-COUNT)
                   PERFORM 2331-MOVE-BYTES-RIGHT 820-SHIFT TIMES
               ELSE
                   COMPUTE 820-SHIFT EQUAL (820-COUNT - 820-BASE)
                   PERFORM 2332-MOVE-BYTES-LEFT 820-SHIFT TIMES
               END-IF
           END-IF.
       EJECT
      ****************************************************************
      *    2 3 3 1 - M O V E - B Y T E S - R I G H T .               *
      ****************************************************************

       2331-MOVE-BYTES-RIGHT.

           MOVE 200-COBOL-RECORD       TO 820-HOLD-RECORD.
           MOVE SPACES                 TO 820-WORK-RECORD.
           IF 200-COBOL-RECORD (72:1) EQUAL SPACE
               MOVE 200-COBOL-RECORD (8:64)
                                       TO 820-WORK-RECORD
               MOVE 820-WORK-RECORD    TO 200-COBOL-RECORD (9:64).
       SKIP3
      ****************************************************************
      *    2 3 3 2 - M O V E - B Y T E S - L E F T .                 *
      ****************************************************************

       2332-MOVE-BYTES-LEFT.

           MOVE 200-COBOL-RECORD       TO 820-HOLD-RECORD.
           MOVE SPACES                 TO 820-WORK-RECORD.
           IF 200-COBOL-RECORD (8:5) EQUAL SPACES
               MOVE 200-COBOL-RECORD (13:59)
                                       TO 820-WORK-RECORD
               MOVE 820-WORK-RECORD    TO 200-COBOL-RECORD (12:60).
       EJECT
      ****************************************************************
      *    ANALYZE THE PROGRAM TABLE TO PERFORM FIXUPS.              *
      ****************************************************************

       4000-CLEAN-UP-TABLE.

           PERFORM 4100-BUILD-FLOWER-BOXES.

           PERFORM 4200-CLEAN-UP-SECTIONS.

           PERFORM 4300-FIX-UP-EJECTS
               VARYING PL FROM 400-HIGH-USED-PL BY -1
                 UNTIL PL EQUAL (800-ENV-DIV-LINE + 2)
                    OR PL IS LESS THAN 300-COMP-2.

           PERFORM 4400-FIX-UP-EXITS
               VARYING PL FROM 400-HIGH-USED-PL BY -1
                 UNTIL PL EQUAL 800-PROC-DIV-LINE
                    OR PL IS LESS THAN 300-COMP-2.
       EJECT
      ****************************************************************
      *    GENERATE FLOWER-BOX COMMENT LINES, WHERE NEEDED.          *
      ****************************************************************

       4100-BUILD-FLOWER-BOXES.

           PERFORM VARYING PL FROM 1 BY 1
                   UNTIL PL IS GREATER THAN 400-HIGH-USED-PL

               IF 580-LINE-TYPE (PL) EQUAL 300-CHAR-C
                   PERFORM 4110-START-FLOWER-BOX
               END-IF

               IF 580-LINE-TYPE (PL) EQUAL 300-CHAR-P
                   PERFORM 4120-TERMINATE-COMMENT
               END-IF

               IF 580-LINE-TYPE (PL) EQUAL 300-CHAR-C
                   PERFORM 4130-CLOSE-FLOWER-BOX
               END-IF

           END-PERFORM.
       SKIP3
      ****************************************************************
      *    BUILD INITIAL FLOWER-BOX COMMENT LINE.                    *
      ****************************************************************

       4110-START-FLOWER-BOX.

           IF PL EQUAL 300-COMP-1
               MOVE 300-CHAR-P         TO 580-LINE-TYPE (PL)
           ELSE
               IF 580-LINE-TYPE (PL - 1) EQUAL 300-CHAR-ASTERISK
                                            OR 300-CHAR-C
                                            OR 300-CHAR-P
                   CONTINUE
               ELSE
                   MOVE 300-CHAR-P     TO 580-LINE-TYPE (PL)
               END-IF
               IF 580-VERTICAL-ACTION (PL - 1) EQUAL 300-CHAR-E
                                                  OR 300-CHAR-B
                                                  OR 300-CHAR-1
                                                  OR 300-CHAR-2
                                                  OR 300-CHAR-3
                   MOVE 300-CHAR-P     TO 580-LINE-TYPE (PL)
               END-IF
           END-IF.
       EJECT
      ****************************************************************
      *    BUILD FINAL FLOWER-BOX LINE FOR A SINGLE-LINE COMMENT.    *
      ****************************************************************

       4120-TERMINATE-COMMENT.

           IF 580-VERTICAL-ACTION (PL) EQUAL 300-CHAR-E
                                          OR 300-CHAR-B
                                          OR 300-CHAR-1
                                          OR 300-CHAR-2
                                          OR 300-CHAR-3
               MOVE 300-CHAR-B         TO 580-LINE-TYPE (PL)
           END-IF
           IF 580-LINE-TYPE (PL + 1) EQUAL 300-CHAR-ASTERISK
                                        OR 300-CHAR-C
               CONTINUE
           ELSE
               MOVE 300-CHAR-B         TO 580-LINE-TYPE (PL)
           END-IF.
       SKIP3
      ****************************************************************
      *    BUILD FINAL FLOWER-BOX COMMENT LINE.                      *
      ****************************************************************

       4130-CLOSE-FLOWER-BOX.

           IF PL EQUAL 400-HIGH-USED-PL
               MOVE 300-CHAR-F         TO 580-LINE-TYPE (PL)
           ELSE
               IF 580-VERTICAL-ACTION (PL) EQUAL 300-CHAR-E
                                              OR 300-CHAR-B
                                              OR 300-CHAR-1
                                              OR 300-CHAR-2
                                              OR 300-CHAR-3
                   MOVE 300-CHAR-F     TO 580-LINE-TYPE (PL)
               END-IF
               IF 580-LINE-TYPE (PL + 1) EQUAL 300-CHAR-ASTERISK
                                            OR 300-CHAR-C
                   CONTINUE
               ELSE
                   MOVE 300-CHAR-F     TO 580-LINE-TYPE (PL)
               END-IF
           END-IF.
       EJECT
      ****************************************************************
      *    CLEAN UP DIVISION AND SECTION HEADERS FOR TRAILING LINES. *
      ****************************************************************

       4200-CLEAN-UP-SECTIONS.

           IF 800-ID-DIV-LINE IS GREATER THAN ZERO
               SET PL                  TO 800-ID-DIV-LINE
               MOVE 600-ID-DIV-HEADER  TO 580-COBOL-DATA (PL)
               MOVE 300-CHAR-B         TO 580-VERTICAL-ACTION (PL).
           IF 800-ENV-DIV-LINE IS GREATER THAN ZERO
               SET PL                  TO 800-ENV-DIV-LINE
               PERFORM 8150-COMPRESS-AREA-A
               MOVE 300-CHAR-H         TO 580-VERTICAL-ACTION (PL).
           IF 800-CFG-SECT-LINE IS GREATER THAN ZERO
               SET PL                  TO 800-CFG-SECT-LINE
               PERFORM 8150-COMPRESS-AREA-A
               MOVE 300-CHAR-B         TO 580-VERTICAL-ACTION (PL).
           IF 800-IO-SECT-LINE IS GREATER THAN ZERO
               SET PL                  TO 800-IO-SECT-LINE
               PERFORM 8150-COMPRESS-AREA-A
               MOVE 300-CHAR-B         TO 580-VERTICAL-ACTION (PL).
           IF 800-DATA-DIV-LINE IS GREATER THAN ZERO
               SET PL                  TO 800-DATA-DIV-LINE
               PERFORM 8150-COMPRESS-AREA-A
               MOVE 300-CHAR-H         TO 580-VERTICAL-ACTION (PL).
           IF 800-FILE-SECT-LINE IS GREATER THAN ZERO
               SET PL                  TO 800-FILE-SECT-LINE
               PERFORM 8150-COMPRESS-AREA-A
               MOVE 300-CHAR-B         TO 580-VERTICAL-ACTION (PL).
           IF 800-WS-SECT-LINE IS GREATER THAN ZERO
               SET PL                  TO 800-WS-SECT-LINE
               PERFORM 8150-COMPRESS-AREA-A
               IF 800-FILE-SECT-LINE IS GREATER THAN ZERO
                   MOVE 300-CHAR-H     TO 580-VERTICAL-ACTION (PL)
               ELSE
                   MOVE 300-CHAR-B     TO 580-VERTICAL-ACTION (PL).
           IF 800-LINK-SECT-LINE IS GREATER THAN ZERO
               SET PL                  TO 800-LINK-SECT-LINE
               PERFORM 8150-COMPRESS-AREA-A
               IF 800-FILE-SECT-LINE IS GREATER THAN ZERO
               OR 800-WS-SECT-LINE   IS GREATER THAN ZERO
                   MOVE 300-CHAR-H     TO 580-VERTICAL-ACTION (PL)
               ELSE
                   MOVE 300-CHAR-B     TO 580-VERTICAL-ACTION (PL).
           IF 800-PROC-DIV-LINE IS GREATER THAN ZERO
               SET PL                  TO 800-PROC-DIV-LINE
               PERFORM 8150-COMPRESS-AREA-A
               MOVE 300-CHAR-H         TO 580-VERTICAL-ACTION (PL).
           SET PL                      TO 400-HIGH-USED-PL.
           MOVE SPACE                  TO 580-VERTICAL-ACTION (PL).
       EJECT
      ****************************************************************
      *    MOVE BACKWARDS THRU THE TABLE AND FIX UP ALL THE EJECTS   *
      *    SO THEY APPEAR BEFORE ANY FLOWER-BOXES.                   *
      ****************************************************************

       4300-FIX-UP-EJECTS.

           IF 580-VERTICAL-ACTION (PL) EQUAL 300-CHAR-E
               MOVE 300-CHAR-B         TO 580-VERTICAL-ACTION (PL)
               PERFORM UNTIL 580-INDICATOR-AREA (PL) EQUAL SPACE
                          OR PL EQUAL (800-ENV-DIV-LINE + 2)
                   SET PL DOWN BY 1
               END-PERFORM
               MOVE 300-CHAR-E         TO 580-VERTICAL-ACTION (PL)
           END-IF.
       SKIP3
      ****************************************************************
      *    MOVE BACKWARDS THRU THE TABLE AND FIX UP ALL THE EXITS    *
      *    SO THEY DON'T HAVE EJECTS BEFORE THEIR PARAGRAPH NAMES.   *
      ****************************************************************

       4400-FIX-UP-EXITS.

           IF 580-VERTICAL-ACTION (PL) EQUAL 300-CHAR-X
               MOVE SPACE              TO 580-VERTICAL-ACTION (PL)
               PERFORM UNTIL 580-VERTICAL-ACTION (PL) EQUAL 300-CHAR-E
                          OR PL IS EQUAL TO 800-PROC-DIV-LINE
                   SET PL DOWN BY 1
               END-PERFORM
               MOVE 300-CHAR-1         TO 580-VERTICAL-ACTION (PL)
           END-IF.
       EJECT
      ****************************************************************
      *    WRITE THE NEW REFORMATTED COBOL SOURCE PROGRAM.           *
      ****************************************************************

       5000-WRITE-COBOL-PROGRAM.

           MOVE SPACES                 TO 200-COBOL-RECORD.
           MOVE 800-PROGRAM-ID         TO 200-SOURCE-FILE-NAME.
           PERFORM VARYING PL FROM 1 BY 1
                     UNTIL PL IS GREATER THAN 400-HIGH-USED-PL

               IF PL EQUAL 800-CBL2-WS-LINE
                   MOVE SPACES         TO 200-SOURCE-CODE
                   PERFORM 5300-INSERT-DATA-DEFINITION
               END-IF

      *****     DISPLAY 580-PROGRAM-LINE (PL)  ****
               IF 580-LINE-TYPE (PL) EQUAL 300-CHAR-P OR 300-CHAR-B
                   MOVE SPACES         TO 200-SOURCE-CODE
                   MOVE ALL '*'        TO 200-COBOL-RECORD (7:64)
                   PERFORM 8200-WRITE-1-SOURCE-LINE
               END-IF
               IF  88-100-BUILD-PARA-COMMENT
               AND 580-VERTICAL-ACTION (PL) EQUAL 300-CHAR-H
                   PERFORM 5100-BUILD-COMMENT-HEADER
               END-IF

               MOVE 580-COBOL-DATA (PL)
                                       TO 200-COBOL-RECORD (7:66)
               MOVE 800-PROGRAM-ID     TO 200-SOURCE-FILE-NAME
               IF 200-COBOL-RECORD (7:6) EQUAL '.CBL2-'
                   CONTINUE
               ELSE
                   PERFORM 8200-WRITE-1-SOURCE-LINE
                   IF 580-LINE-TYPE (PL) EQUAL 300-CHAR-F OR 300-CHAR-B
                       MOVE SPACES     TO 200-SOURCE-CODE
                       MOVE ALL '*'    TO 200-COBOL-RECORD (7:64)
                       PERFORM 8200-WRITE-1-SOURCE-LINE
                   END-IF
               END-IF

               IF 200-COBOL-RECORD (7:6) EQUAL '.CBL2-'
                   CONTINUE
               ELSE
                   PERFORM 5200-BUILD-POST-LINE
               END-IF
       EJECT
               IF 200-COBOL-RECORD (7:20) EQUAL '.CBL2-WHEN-COMP-LINE'
                   PERFORM 5500-INSERT-WHEN-COMPILED
               END-IF
               IF 200-COBOL-RECORD (7:18) EQUAL '.CBL2-CURDATE-LINE'
                   PERFORM 5600-INSERT-CURDATE
               END-IF
               IF 200-COBOL-RECORD (7:17) EQUAL '.CBL2-CURTOD-LINE'
                   PERFORM 5700-INSERT-CURTOD
               END-IF
               IF PL EQUAL 800-CBL2-ID-LINE
                   PERFORM 8600-INSERT-CONVERSION-NOTE
               END-IF

           END-PERFORM.
       EJECT
      ****************************************************************
      *    GENERATE FLOWER-BOXED COMMENT HEADER.                     *
      ****************************************************************

       5100-BUILD-COMMENT-HEADER.

           MOVE ALL '*'                TO 200-COBOL-RECORD (7:64).
           MOVE 800-PROGRAM-ID         TO 200-SOURCE-FILE-NAME.
           PERFORM 8200-WRITE-1-SOURCE-LINE.

           MOVE 580-COBOL-DATA (PL)    TO 800-HOLD-80-BYTES.
           IF 800-HOLD-80-BYTES (2:9) EQUAL 300-PROCEDURE
               MOVE SPACES             TO 800-HOLD-80-BYTES (21:40)
           END-IF.
           MOVE SPACES                 TO 200-COBOL-RECORD (7:66).
           MOVE 300-CHAR-ASTERISK      TO 200-COBOL-RECORD (7:1).
           MOVE 300-COMP-2             TO 800-I.
           IF 800-HOLD-80-BYTES (30:1) EQUAL SPACE OR 300-CHAR-PERIOD
               MOVE 300-COMP-12        TO 800-J
           ELSE
               MOVE 300-COMP-10        TO 800-J
           END-IF.
           PERFORM 300-COMP-30 TIMES
               MOVE 800-HOLD-80-BYTES (800-I:1)
                                       TO 200-COBOL-RECORD (800-J:1)
               ADD 300-COMP-1          TO 800-I
               ADD 300-COMP-2          TO 800-J
           END-PERFORM.
           MOVE 300-CHAR-ASTERISK      TO 200-COBOL-RECORD (70:1).
           MOVE 800-PROGRAM-ID         TO 200-SOURCE-FILE-NAME.
           PERFORM 8200-WRITE-1-SOURCE-LINE.

           MOVE ALL '*'                TO 200-COBOL-RECORD (7:64).
           MOVE 800-PROGRAM-ID         TO 200-SOURCE-FILE-NAME.
           PERFORM 8200-WRITE-1-SOURCE-LINE.

           PERFORM 8200-WRITE-1-SOURCE-LINE.
       EJECT
      ****************************************************************
      *    GENERATE POST-LINE VERTICAL WHITE SPACE.                  *
      ****************************************************************

       5200-BUILD-POST-LINE.

           EVALUATE 580-VERTICAL-ACTION (PL)
               WHEN 300-CHAR-B
               WHEN 300-CHAR-H
                   PERFORM 8200-WRITE-1-SOURCE-LINE
               WHEN 300-CHAR-E
                   MOVE 300-EJECT      TO 200-COBOL-RECORD (8:5)
                   PERFORM 8200-WRITE-1-SOURCE-LINE
               WHEN 300-CHAR-1
                   MOVE 300-SKIP1      TO 200-COBOL-RECORD (8:5)
                   PERFORM 8200-WRITE-1-SOURCE-LINE
               WHEN 300-CHAR-2
                   MOVE 300-SKIP2      TO 200-COBOL-RECORD (8:5)
                   PERFORM 8200-WRITE-1-SOURCE-LINE
               WHEN 300-CHAR-3
                   MOVE 300-SKIP3      TO 200-COBOL-RECORD (8:5)
                   PERFORM 8200-WRITE-1-SOURCE-LINE
               WHEN OTHER
                   CONTINUE
           END-EVALUATE.
       EJECT
      ****************************************************************
      *    INSERT NEW COBOL II DATA DEFINITIONS.                     *
      ****************************************************************

       5300-INSERT-DATA-DEFINITION.

           IF 88-100-CBL2-COMPILED
           OR 88-100-CBL2-CURDATE
           OR 88-100-CBL2-CURTOD
               MOVE SPACES                 TO 200-SOURCE-CODE
               MOVE 700-DATETIME-LINE-01   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               PERFORM 8600-INSERT-CONVERSION-NOTE
               MOVE 700-DATETIME-LINE-02   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE.

           IF 88-100-CBL2-COMPILED
               MOVE 700-DATETIME-LINE-03   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-04   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-05   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-06   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-07   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-08   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE.

           IF 88-100-CBL2-CURDATE
               MOVE 700-DATETIME-LINE-09   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-10   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-11   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-12   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-13   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-14   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-15   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-16   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-17   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-18   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE.

           IF 88-100-CBL2-CURTOD
               MOVE 700-DATETIME-LINE-19   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               MOVE 700-DATETIME-LINE-20   TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE.

           IF 88-100-CBL2-COMPILED
           OR 88-100-CBL2-CURDATE
           OR 88-100-CBL2-CURTOD
               MOVE 300-EJECT          TO 200-COBOL-RECORD (8:5)
               PERFORM 8200-WRITE-1-SOURCE-LINE.

           IF 400-CICS-PTR-COUNT IS GREATER THAN ZERO
               MOVE SPACES             TO 200-SOURCE-CODE
               MOVE 300-EJECT          TO 200-COBOL-RECORD (8:5)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               PERFORM 8600-INSERT-CONVERSION-NOTE
               MOVE SPACES             TO 200-SOURCE-CODE
               MOVE '01  1000-CBL2-BLL-CELL-POINTERS.'
                                       TO 200-COBOL-RECORD (8:64)
               PERFORM 8200-WRITE-1-SOURCE-LINE
               PERFORM VARYING PT FROM 1 BY 1
                       UNTIL 500-CICS-BLL-ADDR (PT) EQUAL SPACES
                   MOVE SPACES         TO 200-SOURCE-CODE
                   MOVE '05  '         TO 200-COBOL-RECORD (12:4)
                   MOVE 500-CICS-BLL-ADDR (PT)
                                       TO 200-COBOL-RECORD (16:30)
                   MOVE 'PIC 9(08)   COMP.'
                                       TO 200-COBOL-RECORD (48:18)
                   PERFORM 8200-WRITE-1-SOURCE-LINE
                   MOVE '05  '         TO 200-COBOL-RECORD (12:4)
                   MOVE 500-CICS-BLL-PTR (PT)
                                       TO 200-COBOL-RECORD (16:30)
                   MOVE 'REDEFINES'    TO 200-COBOL-RECORD (48:9)
                   PERFORM 8200-WRITE-1-SOURCE-LINE
                   MOVE 500-CICS-BLL-ADDR (PT)
                                       TO 200-COBOL-RECORD (16:30)
                   MOVE 'USAGE IS POINTER.'
                                       TO 200-COBOL-RECORD (48:17)
                   PERFORM 8200-WRITE-1-SOURCE-LINE
               END-PERFORM
               MOVE 300-EJECT          TO 200-COBOL-RECORD (8:5)
               PERFORM 8200-WRITE-1-SOURCE-LINE
           END-IF.
       EJECT
      ****************************************************************
      *    INSERT CODE TO CONVERT 'WHEN-COMPILED'.                   *
      ****************************************************************

       5500-INSERT-WHEN-COMPILED.

           MOVE SPACES                 TO 200-SOURCE-CODE
           MOVE '     MOVE WHEN-COMPILED          TO '
                                       TO 200-COBOL-RECORD (7:63)
           MOVE 'CBL2-ANSI85-WHEN-COMPILED'
                                       TO 200-COBOL-RECORD (43:28)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
           MOVE '     MOVE CBL2-ANSI85-COMP-DATE  TO '
                                       TO 200-COBOL-RECORD (7:63)
           MOVE 'CBL2-ANSI74-COMP-DATE    '
                                       TO 200-COBOL-RECORD (43:28)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
           MOVE '     MOVE CBL2-ANSI85-COMP-TIME  TO '
                                       TO 200-COBOL-RECORD (7:63)
           MOVE 'CBL2-ANSI74-COMP-TIME    '
                                       TO 200-COBOL-RECORD (43:28)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
       EJECT
      ****************************************************************
      *    INSERT CODE TO CONVERT 'CURRENT-DATE'.                    *
      ****************************************************************

       5600-INSERT-CURDATE.

           MOVE SPACES                 TO 200-SOURCE-CODE
           MOVE '     ACCEPT CBL2-ANSI85-DATE   FROM DATE'
                                       TO 200-COBOL-RECORD (7:63)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
           MOVE '     MOVE CBL2-ANSI85-DATE-MM    TO '
                                       TO 200-COBOL-RECORD (7:63)
           MOVE 'CBL2-ANSI74-DATE-MM      '
                                       TO 200-COBOL-RECORD (43:28)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
           MOVE '     MOVE CBL2-ANSI85-DATE-DD    TO '
                                       TO 200-COBOL-RECORD (7:63)
           MOVE 'CBL2-ANSI74-DATE-DD      '
                                       TO 200-COBOL-RECORD (43:28)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
           MOVE '     MOVE CBL2-ANSI85-DATE-YY    TO '
                                       TO 200-COBOL-RECORD (7:63)
           MOVE 'CBL2-ANSI74-DATE-YY      '
                                       TO 200-COBOL-RECORD (43:28)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
       EJECT
      ****************************************************************
      *    INSERT CODE TO CONVERT 'TIME-OF-DAY'.                     *
      ****************************************************************

       5700-INSERT-CURTOD.

           MOVE SPACES                 TO 200-SOURCE-CODE
           MOVE '     ACCEPT CBL2-ANSI85-TIME   FROM TIME'
                                       TO 200-COBOL-RECORD (7:63)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
           MOVE '     MOVE CBL2-ANSI85-TIME       TO '
                                       TO 200-COBOL-RECORD (7:63)
           MOVE 'CBL2-CURTOD              '
                                       TO 200-COBOL-RECORD (43:28)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
       EJECT
      ****************************************************************
      *    T E R M I N A T E   T H E   P R O G R A M .               *
      ****************************************************************

       6000-TERMINATE-PROGRAM.

           PERFORM 6100-CLOSE-THE-FILES.
           PERFORM 6200-DISPLAY-FINAL-MESSAGES.
       SKIP3
      ****************************************************************
      *    C L O S E   D A T A   F I L E S .                         *
      ****************************************************************

       6100-CLOSE-THE-FILES.

           CLOSE SYS001-COBOL-FILE
                 SYS201-PRINT-FILE.
       SKIP3
      ****************************************************************
      *    D I S P L A Y   F I N A L   M E S S A G E S .             *
      ****************************************************************

       6200-DISPLAY-FINAL-MESSAGES.

           MOVE 600-TOTAL-SOURCE-MSG   TO 600-TOTAL-ID.
           MOVE 400-COBOL-LINE-COUNT   TO 600-DISPLAY-TOTAL.
           DISPLAY 600-TOTAL-MESSAGE.

           MOVE 600-OLD-LINES-MSG      TO 600-TOTAL-ID.
           MOVE 400-OLD-LINES-DROPPED  TO 600-DISPLAY-TOTAL.
           DISPLAY 600-TOTAL-MESSAGE.

           COMPUTE 400-NEW-LINES-ADDED EQUAL
               400-PRINT-LINE-COUNT - 400-COBOL-LINE-COUNT
                                    + 400-OLD-LINES-DROPPED.
           MOVE 600-NEW-LINES-MSG      TO 600-TOTAL-ID.
           MOVE 400-NEW-LINES-ADDED    TO 600-DISPLAY-TOTAL.
           DISPLAY 600-TOTAL-MESSAGE.

           MOVE 600-OUT-LINES-MSG      TO 600-TOTAL-ID.
           MOVE 400-PRINT-LINE-COUNT   TO 600-DISPLAY-TOTAL.
           DISPLAY 600-TOTAL-MESSAGE.
       EJECT
      ****************************************************************
      *    COPY ONE INPUT COBOL BYTE INTO THE WORK-TOKEN.            *
      ****************************************************************

       8000-MOVE-ONE-TOKEN-BYTE.

           MOVE 200-SOURCE-CHAR (800-SUB)
                                       TO 210-TOKEN-BYTE (800-SUB2).

           IF 210-TOKEN-BYTE (800-SUB2) IS NUMERIC
               ADD 300-ONE             TO 400-TOKEN-NUMBERS
           ELSE
               IF  210-TOKEN-BYTE (800-SUB2) IS ALPHABETIC
               AND 210-TOKEN-BYTE (800-SUB2) IS GREATER THAN SPACE
                   ADD 300-ONE         TO 400-TOKEN-LETTERS
               ELSE
                   IF 210-TOKEN-BYTE (800-SUB2) EQUAL 300-CHAR-HYPHEN
                       ADD 300-ONE     TO 400-TOKEN-HYPHENS.

           ADD 300-COMP-1              TO 800-SUB.
           ADD 300-COMP-1              TO 800-SUB2.
           ADD 300-ONE                 TO 210-TOKEN-LENGTH.
       EJECT
      ****************************************************************
      *    MODIFY A COMMENT LINE, FORCING STANDARD FORMAT.           *
      ****************************************************************

       8100-ADJUST-COMMENT-LINE.

           MOVE ZERO                   TO 400-STAR-COUNT
           MOVE ZERO                   TO 400-NON-STAR-COUNT
           PERFORM VARYING 800-I FROM 300-COMP-1 BY 300-COMP-1
               UNTIL 800-I IS GREATER THAN 300-LINE-SCAN-LENGTH
               IF 200-SOURCE-CHAR (800-I) EQUAL SPACE
                   CONTINUE
               ELSE
                   IF 200-SOURCE-CHAR (800-I) EQUAL 300-CHAR-ASTERISK
                       ADD 300-ONE     TO 400-STAR-COUNT
                   ELSE
                       ADD 300-ONE     TO 400-NON-STAR-COUNT
                   END-IF
               END-IF
           END-PERFORM.

           IF  400-NON-STAR-COUNT IS EQUAL TO ZERO
           AND 400-STAR-COUNT IS GREATER THAN 300-COMP-2
               MOVE ALL '*'            TO 200-SOURCE-CODE (1:63)
               MOVE SPACES             TO 200-SOURCE-CODE (64:2)
               MOVE 300-CHAR-ASTERISK  TO 580-LINE-TYPE (PL)
           ELSE
               MOVE 300-CHAR-C         TO 580-LINE-TYPE (PL)
               PERFORM VARYING 800-I FROM 300-COMP-65 BY -1
                   UNTIL 800-I IS LESS THAN 300-COMP-4
                   EVALUATE TRUE
                   WHEN 200-SOURCE-CHAR (800-I) EQUAL SPACE
                       CONTINUE
                   WHEN 200-SOURCE-CHAR (800-I) EQUAL 300-CHAR-ASTERISK
                       MOVE SPACE      TO 200-SOURCE-CHAR (800-I)
                   WHEN OTHER
                       MOVE 300-COMP-2 TO 800-I
                   END-EVALUATE
               END-PERFORM
               IF 200-SOURCE-CODE (63:3) EQUAL SPACES
                   MOVE SPACES         TO 200-SOURCE-CODE (63:3)
                   MOVE 300-CHAR-ASTERISK
                                       TO 200-SOURCE-CODE (63:1)
               END-IF
           END-IF.
       EJECT
      ****************************************************************
      *    COMPRESS EXCESS WHITE SPACE IN AREA A.                    *
      ****************************************************************

       8150-COMPRESS-AREA-A.

           MOVE 580-COBOL-DATA (PL) (2:64)
                                       TO 810-COMPRESS-WORK-1.
           MOVE SPACES                 TO 810-COMPRESS-WORK-2.
           PERFORM 8300-COMPRESS-DATA-LINE.
           MOVE 810-COMPRESS-WORK-2    TO 580-COBOL-DATA (PL) (2:64).
       SKIP3
      ****************************************************************
      *    PRINT ONE NEW COBOL SOURCE LINE.                          *
      ****************************************************************

       8200-WRITE-1-SOURCE-LINE.

           ADD 300-ONE                 TO 400-PRINT-LINE-COUNT.
           MOVE 400-PRINT-LINE-COUNT   TO 800-NEW-LINE-N.
           MOVE 800-NEW-LINE-X         TO 200-LINE-NUMBER.
           MOVE 800-PROGRAM-ID         TO 200-SOURCE-FILE-NAME.
           WRITE SYS201-PRINT-RECORD FROM 200-COBOL-RECORD.
           MOVE SPACES                 TO 200-COBOL-RECORD (7:66).
       EJECT
      ****************************************************************
      *    8 3 0 0 - C O M P R E S S - D A T A - L I N E .           *
      ****************************************************************

       8300-COMPRESS-DATA-LINE.

           SET 810-SI TO 1.
           SET 810-DI TO 1.
           PERFORM UNTIL 810-SOURCE-CHAR (810-SI) NOT EQUAL SPACE
                      OR 810-SI IS GREATER THAN 300-COMP-65
               SET 810-SI UP BY 1
           END-PERFORM.

           SET 88-100-NO-QUOTE-FOUND TO TRUE.
           PERFORM UNTIL 810-SI IS GREATER THAN 300-COMP-65
               IF  810-SOURCE-CHAR (810-SI) EQUAL QUOTE
                   IF 88-100-QUOTE-WAS-FOUND
                       SET 88-100-NO-QUOTE-FOUND TO TRUE
                   ELSE
                       SET 88-100-QUOTE-WAS-FOUND TO TRUE
                   END-IF
               END-IF
               MOVE 810-SOURCE-CHAR (810-SI)
                                       TO 810-TARGET-CHAR (810-DI)
               SET 810-SI UP BY 1
               IF  810-SOURCE-CHAR (810-SI - 1) EQUAL SPACE
               AND 810-SOURCE-CHAR (810-SI)     EQUAL SPACE
               AND 88-100-NO-QUOTE-FOUND
                   CONTINUE
               ELSE
                   SET 810-DI UP BY 1
               END-IF
           END-PERFORM.
       EJECT
      ****************************************************************
      *    8 4 0 0 - S H I F T - S T R I N G - R I G H T .           *
      ****************************************************************

       8400-SHIFT-STRING-RIGHT.

           IF  200-SOURCE-CHAR (300-COMP-65) EQUAL SPACE
               MOVE SPACES             TO 810-COMPRESS-WORK-2
               COMPUTE 800-C3 EQUAL 300-COMP-65 - 800-C2 + 300-COMP-1
               MOVE 200-SOURCE-CODE (800-C2 : 800-C3)
                   TO 810-COMPRESS-WORK-2 (2 : 800-C3 - 1)
               IF 810-COMPRESS-WORK-2 (300-COMP-65 : 1) EQUAL SPACE
                   MOVE 810-COMPRESS-WORK-2
                       TO 200-SOURCE-CODE (800-C2 : 800-C3)
                   ADD 300-COMP-1      TO 800-C2
               ELSE
                   MOVE 800-HOLD-80-BYTES
                                       TO 200-COBOL-RECORD
                   MOVE 300-COMP-65    TO 800-C2
               END-IF
               IF 800-C2 EQUAL 17 OR 21 OR 25 OR 29 OR 33
                            OR 37 OR 41 OR 45 OR 49
                   MOVE 200-COBOL-RECORD
                                       TO 800-HOLD-80-BYTES
               END-IF
           ELSE
               MOVE 800-HOLD-80-BYTES  TO 200-COBOL-RECORD
               MOVE 300-COMP-65        TO 800-C2
           END-IF.
       EJECT
      ****************************************************************
      *    8 5 0 0 - I N S E R T - A - N O H A N D L E .             *
      ****************************************************************

       8500-INSERT-A-NOHANDLE.

           IF  88-100-CICS-EXEC-FOUND
           AND (88-100-END-EXEC-FOUND OR 88-100-END-EXECP-FOUND)
      ****************************************************************
               IF 88-100-VALID-NOHANDLE
                   ADD 300-COMP-1      TO 400-HIGH-USED-PL
                   SET PL              TO 400-HIGH-USED-PL
                   MOVE SPACES         TO 810-COMPRESS-WORK-AREA
                   MOVE 300-NOHANDLE   TO 810-COMPRESS-WORK-AREA
                            (400-CICS-EXEC-POS + 5 : 8)
                   MOVE 810-COMPRESS-WORK-AREA
                                       TO 580-COBOL-DATA (PL)
                   ADD 300-ONE         TO 400-TABLE-LINE-COUNT
               END-IF
      ****************************************************************
               ADD 300-COMP-1          TO 400-HIGH-USED-PL
               SET PL                  TO 400-HIGH-USED-PL
               MOVE SPACES             TO 810-COMPRESS-WORK-AREA
               IF 88-100-END-EXECP-FOUND
                   MOVE 300-END-EXECP  TO 810-COMPRESS-WORK-AREA
                            (400-CICS-EXEC-POS + 1 : 9)
               ELSE
                   MOVE 300-END-EXEC   TO 810-COMPRESS-WORK-AREA
                            (400-CICS-EXEC-POS + 1 : 8)
               END-IF
               MOVE 810-COMPRESS-WORK-AREA
                                       TO 580-COBOL-DATA (PL)
               ADD 300-ONE             TO 400-TABLE-LINE-COUNT
      ****************************************************************
               MOVE ZERO               TO 400-CICS-EXEC-POS
               SET 88-100-END-EXEC-PROCESSED TO TRUE
               SET 88-100-NO-END-EXEC-FOUND  TO TRUE
           END-IF.
       EJECT
      ****************************************************************
      *    INSERT COBOL II CONVERSION DATE/TIME STAMP COMMENTS.      *
      ****************************************************************

       8600-INSERT-CONVERSION-NOTE.

           MOVE SPACES                 TO 200-SOURCE-CODE
           MOVE ALL '*'                TO 200-COBOL-RECORD (7:64)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
           MOVE '*    CONVERTED TO COBOL-II (ANSI-85)'
                                       TO 200-COBOL-RECORD (7:63)
           MOVE 800-CURRENT-DATE       TO 200-COBOL-RECORD (45:8)
           MOVE 600-RUN-TIME           TO 200-COBOL-RECORD (55:8)
           MOVE '*'                    TO 200-COBOL-RECORD (70:1)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
           MOVE ALL '*'                TO 200-COBOL-RECORD (7:64)
           PERFORM 8200-WRITE-1-SOURCE-LINE.
           MOVE SPACES                 TO 200-SOURCE-CODE
           PERFORM 8200-WRITE-1-SOURCE-LINE.
       SKIP3
      ****************************************************************
      *    E N D   P R O G R A M   C B 2 A L I G N .                 *
      ****************************************************************

       END PROGRAM CB2ALIGN.
